/*!
 * Quasar Framework v0.5.0
 * (c) 2016 Razvan Stoenescu
 * Released under the MIT License.
 */
(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory(require('velocity-animate'), require('velocity-animate/velocity.ui'), require('hammerjs'), require('fastclick')) :
  typeof define === 'function' && define.amd ? define(['velocity-animate', 'velocity-animate/velocity.ui', 'hammerjs', 'fastclick'], factory) :
  (global.Quasar = factory(global.Velocity,global.velui,global.Hammer,global.FastClick));
}(this, function (Velocity$1,velocityAnimate_velocity_ui,Hammer,FastClick) { 'use strict';

  Velocity$1 = 'default' in Velocity$1 ? Velocity$1['default'] : Velocity$1;
  Hammer = 'default' in Hammer ? Hammer['default'] : Hammer;
  FastClick = 'default' in FastClick ? FastClick['default'] : FastClick;

  var transitionSlide = {
    css: false,

    enter: function enter(el, done) {
      Velocity(el, 'stop');
      Velocity(el, 'slideDown', done);
    },
    enterCancelled: function enterCancelled(el) {
      Velocity(el, 'stop');
    },
    leave: function leave(el, done) {
      Velocity(el, 'stop');
      Velocity(el, 'slideUp', done);
    },
    leaveCancelled: function leaveCancelled(el) {
      Velocity(el, 'stop');
    }
  };

  function GridSelectedFilter (data, filter, selectionMode, singleSelection) {
    if (!filter || selectionMode === 'none') {
      return data;
    }

    if (selectionMode === 'single') {
      return singleSelection;
    }

    return data.filter(function (row) {
      return row.__selected;
    });
  }

  function directiveAttr (attribs, oldAttribs) {
    var _this = this;

    if (typeof attribs === 'undefined') {
      console.error('v-attr received empty new value from "' + oldAttribs + '"', this.el);
      return;
    }

    var values = Array.isArray(attribs) ? attribs : [attribs];

    if (typeof oldAttribs !== 'undefined') {
      var oldValues = Array.isArray(oldAttribs) ? oldAttribs : [oldAttribs];

      oldValues = oldValues.filter(function (val) {
        return !values.includes(val);
      });
      oldValues.forEach(function (val) {
        _this.el.removeAttribute(val);
      });
    }

    values.forEach(function (value) {
      _this.el.setAttribute(value, '');
    });
  }

  var directiveCollapsible = {
    bind: function bind() {
      var _this = this;

      this.clickHandler = function () {
        _this.el.classList.toggle('active');

        if (!_this.free) {
          [].slice.call(_this.el.parentNode.children).forEach(function (li) {
            if (li !== _this.el) {
              li.classList.remove('active');
            }
          });
        }
      };

      this.el.children[0].addEventListener('click', this.clickHandler);
    },
    update: function update() {
      this.free = !!this.modifiers.free;
    },
    unbind: function unbind() {
      this.el.children[0].removeEventListener('click', this.clickHandler);
    }
  };

  function getUserAgent() {
    return (navigator.userAgent || navigator.vendor || window.opera).toLowerCase();
  }

  function getMatch(userAgent, platformMatch) {
    var match = /(edge)\/([\w.]+)/.exec(userAgent) || /(opr)[\/]([\w.]+)/.exec(userAgent) || /(chrome)[\/]([\w.]+)/.exec(userAgent) || /(iemobile)[\/]([\w.]+)/.exec(userAgent) || /(version)(applewebkit)[\/]([\w.]+).*(safari)[\/]([\w.]+)/.exec(userAgent) || /(webkit)[\/]([\w.]+).*(version)[\/]([\w.]+).*(safari)[\/]([\w.]+)/.exec(userAgent) || /(webkit)[\/]([\w.]+)/.exec(userAgent) || /(opera)(?:.*version|)[\/]([\w.]+)/.exec(userAgent) || /(msie) ([\w.]+)/.exec(userAgent) || userAgent.indexOf('trident') >= 0 && /(rv)(?::| )([\w.]+)/.exec(userAgent) || userAgent.indexOf('compatible') < 0 && /(mozilla)(?:.*? rv:([\w.]+)|)/.exec(userAgent) || [];

    return {
      browser: match[5] || match[3] || match[1] || '',
      version: match[2] || match[4] || '0',
      versionNumber: match[4] || match[2] || '0',
      platform: platformMatch[0] || ''
    };
  }

  function getPlatformMatch(userAgent) {
    return (/(ipad)/.exec(userAgent) || /(ipod)/.exec(userAgent) || /(windows phone)/.exec(userAgent) || /(iphone)/.exec(userAgent) || /(kindle)/.exec(userAgent) || /(silk)/.exec(userAgent) || /(android)/.exec(userAgent) || /(win)/.exec(userAgent) || /(mac)/.exec(userAgent) || /(linux)/.exec(userAgent) || /(cros)/.exec(userAgent) || /(playbook)/.exec(userAgent) || /(bb)/.exec(userAgent) || /(blackberry)/.exec(userAgent) || []
    );
  }

  function getPlatform() {
    var userAgent = getUserAgent(),
        platformMatch = getPlatformMatch(userAgent),
        matched = getMatch(userAgent, platformMatch),
        browser = {};

    if (matched.browser) {
      browser[matched.browser] = true;
      browser.version = matched.version;
      browser.versionNumber = parseInt(matched.versionNumber, 10);
    }

    if (matched.platform) {
      browser[matched.platform] = true;
    }

    if (browser.android || browser.bb || browser.blackberry || browser.ipad || browser.iphone || browser.ipod || browser.kindle || browser.playbook || browser.silk || browser['windows phone']) {
      browser.mobile = true;
    }

    if (browser.ipod || browser.ipad || browser.iphone) {
      browser.ios = true;
    }

    if (browser['windows phone']) {
      browser.winphone = true;
      delete browser['windows phone'];
    }

    if (browser.cros || browser.mac || browser.linux || browser.win) {
      browser.desktop = true;
    }

    if (browser.chrome || browser.opr || browser.safari) {
      browser.webkit = true;
    }

    if (browser.rv || browser.iemobile) {
      matched.browser = 'ie';
      browser.ie = true;
    }

    if (browser.edge) {
      matched.browser = 'edge';
      browser.edge = true;
    }

    if (browser.safari && browser.blackberry || browser.bb) {
      matched.browser = 'blackberry';
      browser.blackberry = true;
    }

    if (browser.safari && browser.playbook) {
      matched.browser = 'playbook';
      browser.playbook = true;
    }

    if (browser.opr) {
      matched.browser = 'opera';
      browser.opera = true;
    }

    if (browser.safari && browser.android) {
      matched.browser = 'android';
      browser.android = true;
    }

    if (browser.safari && browser.kindle) {
      matched.browser = 'kindle';
      browser.kindle = true;
    }

    if (browser.safari && browser.silk) {
      matched.browser = 'silk';
      browser.silk = true;
    }

    browser.name = matched.browser;
    browser.platform = matched.platform;

    if (window._cordovaNative) {
      browser.cordova = true;
    }

    return browser;
  }

  var Platform = {
    is: getPlatform(),
    has: {
      touch: function () {
        return !!('ontouchstart' in document.documentElement) || window.navigator.msMaxTouchPoints > 0;
      }()
    },
    within: {
      iframe: window.self !== window.top
    }
  };

  var template = "<div class=\"modal-header\">\n  {{{* title || ''}}}\n</div>\n<div v-if=\"message\" class=\"modal-body modal-scroll\">\n  <p>{{{* message}}}</p>\n</div>\n<div v-if=\"inputs\" class=\"modal-body modal-scroll\">\n  <div v-for=\"input in inputs\" class=\"item floating-label\">\n    <div class=\"item-content\">\n      <input type=\"text\" v-model=\"input.model\" required autofocus>\n      <label>{{ input.label }}</label>\n    </div>\n  </div>\n</div>\n<div v-if=\"radios\" class=\"modal-controls modal-scroll\">\n  <label v-for=\"radio in radios\" class=\"item\">\n    <quasar-radio :model.sync=\"radioModel\" :value.once=\"radio.value\"></quasar-radio>\n    <div class=\"item-content\">\n      {{{* radio.label}}}\n    </div>\n  </label>\n</div>\n<div v-if=\"checkboxes\" class=\"modal-controls modal-scroll\">\n  <label v-for=\"checkbox in checkboxes\" class=\"item\">\n    <quasar-checkbox :model.sync=\"checkbox.checked\"></quasar-checkbox>\n    <div class=\"item-content\">\n      {{{* checkbox.label}}}\n    </div>\n  </label>\n</div>\n<div v-if=\"toggles\" class=\"modal-controls modal-scroll\">\n  <label v-for=\"toggle in toggles\" class=\"item\">\n    <div class=\"item-content\">\n      <div class=\"item-label\">\n        {{{* toggle.label}}}\n      </div>\n      <quasar-toggle :model.sync=\"toggle.checked\"></quasar-toggle>\n    </div>\n  </label>\n</div>\n<div v-if=\"ranges\" class=\"modal-controls modal-scroll list\">\n  <template v-for=\"range in ranges\">\n    <div v-if=\"range.label\" class=\"list-header\">{{{* range.label}}}: {{range.value}}</div>\n    <div class=\"item\">\n      <i v-if=\"range.iconMin\" class=\"item-right-margin\">{{* range.iconMin}}</i>\n      <div v-else class=\"item-right-margin\">{{* range.min}}</div>\n\n      <quasar-range :model.sync=\"range.value\" :min.once=\"range.min\" :max.once=\"range.max\"></quasar-range>\n\n      <i v-if=\"range.iconMax\" class=\"item-left-margin\">{{* range.iconMax}}</i>\n      <div v-else class=\"item-left-margin\">{{* range.max}}</div>\n    </div>\n  </template>\n</div>\n<div v-if=\"progress\" class=\"modal-slim-body\">\n  <quasar-progress\n    :model=\"progress.model\"\n    class=\"primary stripe\"\n    :class=\"{indeterminate: progress.indeterminate}\"\n  ></quasar-progress>\n  <span v-if=\"!progress.indeterminate\">\n    {{progress.model}} %\n  </span>\n</div>\n<div\n  v-if=\"buttons\"\n  class=\"modal-buttons\"\n  :class=\"{row: !stackButtons, column: stackButtons}\"\n>\n  <button\n    v-for=\"button in buttons\"\n    class=\"primary clear\"\n    @click=\"button.handler(getData()), close()\"\n  >\n    {{{* button.label}}}\n  </button>\n</div>\n";

  function set(theme$$) {
    if (theme) {
      document.body.classList.remove(theme);
    }

    theme = theme$$;
    document.body.classList.add(theme$$);
  }

  var theme;

var theme$1 = Object.freeze({
    set: set,
    get current () { return theme; }
  });

  var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) {
    return typeof obj;
  } : function (obj) {
    return obj && typeof Symbol === "function" && obj.constructor === Symbol ? "symbol" : typeof obj;
  };

  var classCallCheck = function (instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  };

  var createClass = function () {
    function defineProperties(target, props) {
      for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];
        descriptor.enumerable = descriptor.enumerable || false;
        descriptor.configurable = true;
        if ("value" in descriptor) descriptor.writable = true;
        Object.defineProperty(target, descriptor.key, descriptor);
      }
    }

    return function (Constructor, protoProps, staticProps) {
      if (protoProps) defineProperties(Constructor.prototype, protoProps);
      if (staticProps) defineProperties(Constructor, staticProps);
      return Constructor;
    };
  }();

  var duration = 300;

  var Modal = function () {
    function Modal(userVm) {
      var _this = this;

      classCallCheck(this, Modal);

      if (!userVm) {
        throw new Error('Modal needs a VueModel.');
      }
      if (!userVm.template) {
        throw new Error('Modal needs a template.');
      }

      var vm = Utils.extend(true, userVm);

      vm.template = '<div class="modal hidden fullscreen flex items-center justify-center">\n          <div v-el:backdrop class="modal-backdrop backdrop"></div>\n          <div v-el:content class="modal-content">' + userVm.template + '</div></div>';
      vm.methods = vm.methods || {};
      vm.methods.close = function (onClose) {
        _this.close(onClose);
      };

      vm.data = userVm.data;

      this.vm = new Vue(vm);
      this.vm.$mount().$appendTo(document.body);

      this.$el = this.vm.$el;
      this.$backdrop = this.vm.$els.backdrop;
      this.$content = this.vm.$els.content;

      this.__onShowHandlers = [];
      this.__onCloseHandlers = [];
      this.selfDestroy = true;
    }

    createClass(Modal, [{
      key: 'show',
      value: function show(onShow) {
        var _this2 = this;

        if (!this.$el.closest('body')) {
          throw new Error('Modal was previously destroyed. Create another one.');
        }

        if (this.minimized && this.maximized) {
          throw new Error('Modal cannot be minimized & maximized simultaneous.');
        }

        this.$content.classList.remove('minimized', 'maximized');
        if (this.minimized) {
          this.$content.classList.add('minimized');
        }
        if (this.maximized) {
          this.$content.classList.add('maximized');
        }

        var effect = void 0,
            options = {
          duration: duration,
          complete: function complete() {
            _this2.__onShowHandlers.forEach(function (handler) {
              handler();
            });
            if (typeof onShow === 'function') {
              onShow();
            }
          }
        };

        if (this.transitionIn) {
          effect = this.transitionIn;
        } else if (theme === 'mat') {
          effect = 'transition.slideUpIn';
        } else if (!this.minimized && (this.maximized || Utils.dom.viewport().width <= 600)) {
          effect = { translateX: [0, '101%'] };
        } else {
          effect = 'transition.shrinkIn';
        }

        this.$el.classList.remove('hidden');
        Velocity(this.$content, effect, options);
        if (!this.maximized) {
          this.$backdrop.classList.add('active');
        }

        return this;
      }
    }, {
      key: 'close',
      value: function close(onClose) {
        var _this3 = this;

        var effect = void 0,
            options = {
          duration: duration,
          complete: function complete() {
            if (_this3.selfDestroy) {
              _this3.destroy();
            }
            _this3.__onCloseHandlers.forEach(function (handler) {
              handler();
            });
            if (typeof onClose === 'function') {
              onClose();
            }
          }
        };

        if (this.transitionOut) {
          effect = this.transitionOut;
        } else if (!this.minimized && (this.maximized || Utils.dom.viewport().width <= 600)) {
          effect = theme === 'ios' ? { translateX: ['101%', 0] } : 'transition.slideDownOut';
        } else {
          effect = theme === 'ios' ? 'transition.shrinkOut' : 'transition.expandOut';
        }

        this.$backdrop.classList.remove('active');
        Velocity(this.$content, effect, options);

        return this;
      }
    }, {
      key: 'onShow',
      value: function onShow(handler) {
        this.__trigger('onShow', handler);
        return this;
      }
    }, {
      key: 'onClose',
      value: function onClose(handler) {
        this.__trigger('onClose', handler);
        return this;
      }
    }, {
      key: '__trigger',
      value: function __trigger(event, handler) {
        if (typeof handler !== 'function') {
          throw new Error('Modal ' + event + ' handler must be a function.');
        }

        this['__' + event + 'Handlers'].push(handler);
        return this;
      }
    }, {
      key: 'set',
      value: function set(properties) {
        var _this4 = this;

        if (properties !== Object(properties)) {
          throw new Error('Modal.set() needs an object as parameter.');
        }

        Object.keys(properties).forEach(function (property) {
          _this4[property] = properties[property];
        });

        return this;
      }
    }, {
      key: 'css',
      value: function css(properties) {
        if (properties !== Object(properties)) {
          throw new Error('Modal.css() needs an object as parameter.');
        }

        Utils.dom.css(this.$content, properties);
        return this;
      }
    }, {
      key: 'destroy',
      value: function destroy() {
        if (this.vm) {
          this.vm.$destroy();
        }
        this.$el.remove();
      }
    }]);
    return Modal;
  }();

  var Modal$1 = {
    create: function create(vm) {
      return new Modal(vm);
    }
  };

  function parseButtons(buttons) {
    if (buttons === false) {
      return false;
    }

    if (!Array.isArray(buttons)) {
      throw new Error('Dialog buttons parameter must be an array.');
    }

    if (buttons.some(function (button) {
      return typeof button !== 'string' && (Object(button) !== button || typeof button.label === 'undefined' || typeof button.handler !== 'function');
    })) {
      throw new Error('At least one of Dialog\'s button parameter is neither a string nor an object with both label handler.');
    }

    return buttons.map(function (button) {
      if (typeof button === 'string') {
        return {
          label: button,
          handler: function handler() {}
        };
      }
      return button;
    });
  }

  function parseInputs(inputs) {
    if (!Array.isArray(inputs)) {
      throw new Error('Dialog inputs parameter must be an array.');
    }

    return inputs.map(function (input) {
      input.model = input.model || '';
      return input;
    });
  }

  function parseRadios(radios) {
    if (!Array.isArray(radios)) {
      throw new Error('Dialog radios parameter must be an array.');
    }

    if (radios.some(function (radio) {
      return typeof radio.label === 'undefined' || typeof radio.value === 'undefined';
    })) {
      throw new Error('One of Dialog\'s radio parameter is missing either label or value');
    }

    var selectedValue = radios.filter(function (radio) {
      return radio.selected;
    });

    if (selectedValue.length === 0) {
      return radios[0].value;
    }

    if (selectedValue.length > 1) {
      throw new Error('Multiple Dialog radio parameters are selected.');
    }

    return selectedValue[0].value;
  }

  function parseCheckboxes(checkboxes) {
    if (!Array.isArray(checkboxes)) {
      throw new Error('Dialog checkboxes parameter must be an array.');
    }

    if (checkboxes.some(function (checkbox) {
      return typeof checkbox.label === 'undefined' || typeof checkbox.value === 'undefined';
    })) {
      throw new Error('One of Dialog\'s checkbox parameter is missing either label or value');
    }

    return checkboxes.map(function (checkbox) {
      checkbox.checked = checkbox.checked || false;
      return checkbox;
    });
  }

  function parseRanges(ranges) {
    if (!Array.isArray(ranges)) {
      throw new Error('Dialog ranges parameter must be an array.');
    }

    if (ranges.some(function (range) {
      return typeof range.min === 'undefined' || typeof range.max === 'undefined';
    })) {
      throw new Error('One of Dialog\'s range parameter is missing either min or max');
    }

    return ranges.map(function (range) {
      range.value = range.value || range.min;
      return range;
    });
  }

  function parseProgress(progress) {
    if (progress !== Object(progress)) {
      throw new Error('Progress property is not an Object.');
    }

    if (!progress.hasOwnProperty('model') && !progress.indeterminate) {
      throw new Error('Specify either a model or set as indeterminate.');
    }

    return progress;
  }

  function create(options) {
    var data = Utils.extend({}, options);

    if (typeof data.buttons === 'undefined') {
      data.buttons = [{ label: 'Ok', handler: function handler() {}
      }];
    } else {
      data.buttons = parseButtons(data.buttons);
    }

    if (data.inputs) {
      data.inputs = parseInputs(data.inputs);
    } else if (data.radios) {
      data.radioModel = parseRadios(data.radios);
    } else if (data.checkboxes) {
      data.checkboxes = parseCheckboxes(data.checkboxes);
    } else if (data.toggles) {
      data.toggles = parseCheckboxes(data.toggles);
    } else if (data.ranges) {
      data.ranges = parseRanges(data.ranges);
    } else if (data.progress) {
      data.progress = parseProgress(data.progress);
    }

    return Modal$1.create({
      template: template,
      data: data,
      methods: {
        getData: function getData() {
          if (this.inputs) {
            return this.inputs.map(function (input) {
              return {
                name: input.name,
                value: input.model
              };
            });
          }
          if (this.radios) {
            return this.radioModel;
          }
          if (this.checkboxes || this.toggles) {
            return (this.checkboxes || this.toggles).filter(function (checkbox) {
              return checkbox.checked;
            }).map(function (checkbox) {
              return checkbox.value;
            });
          }
          if (this.ranges) {
            return this.ranges.map(function (range) {
              return {
                label: range.label,
                value: range.value
              };
            });
          }
          if (this.progress && !this.progress.indeterminate) {
            return this.progress.model;
          }
        }
      }
    }).set({
      minimized: true
    });
  }

  var Dialog = {
    create: create
  };

  var openURL = (function (url) {
    if (Platform.is.cordova) {
      navigator.app.loadUrl(url, {
        openExternal: true
      });

      return;
    }

    var win = window.open(url, '_blank');

    if (win) {
      win.focus();
    } else {
      Dialog.create({
        title: 'Cannot Open Window',
        message: 'Please allow popups first, then please try again.'
      }).show();
    }
  });

  var now = Date.now;

  function debounce (func, wait, immediate) {
    var timeout = void 0,
        args = void 0,
        context = void 0,
        timestamp = void 0,
        result = void 0,
        later = function later() {
      var last = now() - timestamp;

      if (last < wait && last >= 0) {
        timeout = setTimeout(later, wait - last);
      } else {
        timeout = null;
        if (!immediate) {
          result = func.apply(context, args);
          if (!timeout) {
            context = args = null;
          }
        }
      }
    };

    return function () {
      for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      var callNow = immediate && !timeout;

      context = this;
      timestamp = now();

      if (!timeout) {
        timeout = setTimeout(later, wait);
      }
      if (callNow) {
        result = func.apply(context, args);
        context = args = null;
      }

      return result;
    };
  }

  function offset(el) {
    var rect = el.getBoundingClientRect();

    return {
      top: rect.top,
      left: rect.left
    };
  }

  function style(el, property) {
    return window.getComputedStyle(el).getPropertyValue(property);
  }

  function height(el) {
    return parseInt(window.getComputedStyle(el).getPropertyValue('height'), 10);
  }

  function width(el) {
    return parseInt(window.getComputedStyle(el).getPropertyValue('width'), 10);
  }

  function css(element, css) {
    var style = element.style;

    Object.keys(css).forEach(function (prop) {
      style[prop] = css[prop];
    });
  }

  function viewport() {
    var e = window,
        a = 'inner';

    if (!('innerWidth' in window)) {
      a = 'client';
      e = document.documentElement || document.body;
    }

    return {
      width: e[a + 'Width'],
      height: e[a + 'Height']
    };
  }

  function ready(fn) {
    if (typeof fn !== 'function') {
      return;
    }

    if (document.readyState === 'complete') {
      return fn();
    }

    document.addEventListener('DOMContentLoaded', fn, false);
  }

var dom = Object.freeze({
    offset: offset,
    style: style,
    height: height,
    width: width,
    css: css,
    viewport: viewport,
    ready: ready
  });

  var toString = Object.prototype.toString;
  var hasOwn = Object.prototype.hasOwnProperty;
  var class2type = {};
  'Boolean Number String Function Array Date RegExp Object'.split(' ').forEach(function (name) {
    class2type['[object ' + name + ']'] = name.toLowerCase();
  });

  function type(obj) {
    return obj == null ? String(obj) : class2type[toString.call(obj)] || 'object';
  }

  function isPlainObject(obj) {
    if (!obj || type(obj) !== 'object') {
      return false;
    }

    if (obj.constructor && !hasOwn.call(obj, 'constructor') && !hasOwn.call(obj.constructor.prototype, 'isPrototypeOf')) {
      return false;
    }

    var key = void 0;
    for (key in obj) {}

    return key === undefined || hasOwn.call(obj, key);
  }

  function extend() {
    var options = void 0,
        name = void 0,
        src = void 0,
        copy = void 0,
        copyIsArray = void 0,
        clone = void 0,
        target = arguments[0] || {},
        i = 1,
        length = arguments.length,
        deep = false;

    if (typeof target === 'boolean') {
      deep = target;
      target = arguments[1] || {};
      i = 2;
    }

    if ((typeof target === 'undefined' ? 'undefined' : _typeof(target)) !== 'object' && type(target) !== 'function') {
      target = {};
    }

    if (length === i) {
      target = this;
      i--;
    }

    for (; i < length; i++) {
      if ((options = arguments[i]) != null) {
        for (name in options) {
          src = target[name];
          copy = options[name];

          if (target === copy) {
            continue;
          }

          if (deep && copy && (isPlainObject(copy) || (copyIsArray = type(copy) === 'array'))) {
            if (copyIsArray) {
              copyIsArray = false;
              clone = src && type(src) === 'array' ? src : [];
            } else {
              clone = src && isPlainObject(src) ? src : {};
            }

            target[name] = extend(deep, clone, copy);
          } else if (copy !== undefined) {
            target[name] = copy;
          }
        }
      }
    }

    return target;
  }

  var keycodes = {
    'backspace': 8,
    'tab': 9,
    'enter': 13,
    'shift': 16,
    'ctrl': 17,
    'alt': 18,
    'pause': 19,
    'break': 19,
    'caps_lock': 20,
    'escape': 27,
    'space': 32,
    'page_up': 33,
    'page_down': 34,
    'end': 35,
    'home': 36,
    'left_arrow': 37,
    'up_arrow': 38,
    'right_arrow': 39,
    'down_arrow': 40,
    'insert': 45,
    'delete': 46,
    '0': 48,
    '1': 49,
    '2': 50,
    '3': 51,
    '4': 52,
    '5': 53,
    '6': 54,
    '7': 55,
    '8': 56,
    '9': 57,
    'a': 65,
    'b': 66,
    'c': 67,
    'd': 68,
    'e': 69,
    'f': 70,
    'g': 71,
    'h': 72,
    'i': 73,
    'j': 74,
    'k': 75,
    'l': 76,
    'm': 77,
    'n': 78,
    'o': 79,
    'p': 80,
    'q': 81,
    'r': 82,
    's': 83,
    't': 84,
    'u': 85,
    'v': 86,
    'w': 87,
    'x': 88,
    'y': 89,
    'z': 90,
    'left_window_key': 91,
    'right_window_key': 92,
    'select_key': 93,
    'numpad_0': 96,
    'numpad_1': 97,
    'numpad_2': 98,
    'numpad_3': 99,
    'numpad_4': 100,
    'numpad_5': 101,
    'numpad_6': 102,
    'numpad_7': 103,
    'numpad_8': 104,
    'numpad_9': 105,
    'multiply': 106,
    'add': 107,
    'subtract': 109,
    'decimal_point': 110,
    'divide': 111,
    'f1': 112,
    'f2': 113,
    'f3': 114,
    'f4': 115,
    'f5': 116,
    'f6': 117,
    'f7': 118,
    'f8': 119,
    'f9': 120,
    'f10': 121,
    'f11': 122,
    'f12': 123,
    'num_lock': 144,
    'scroll_lock': 145,
    'semicolon': 186,
    'equal_sign': 187,
    'comma': 188,
    'dash': 189,
    'period': 190,
    'forward_slash': 191,
    'grave_accent': 192,
    'open_bracket': 219,
    'back_slash': 220,
    'close_braket': 221,
    'single_quote': 222
  };

  var Utils = {
    openURL: openURL,
    debounce: debounce,
    extend: extend,
    dom: dom,
    keycodes: keycodes
  };

  var directiveScrollFire = {
    bind: function bind() {
      this.scrollContainer = this.el.closest('.layout-view');
      if (!this.scrollContainer) {
        this.scrollContainer = document.getElementById('quasar-app');
      }
    },
    update: function update(handler) {
      var _this = this;

      if (this.scroll) {
        this.scrollContainer.removeEventListener('scroll', this.scroll);
      }

      if (typeof handler !== 'function') {
        this.scroll = function () {};
        console.error('v-scroll-fire requires a function as parameter', this.el);
        return;
      }

      this.scroll = Utils.debounce(function () {
        var containerBottom = Utils.dom.offset(_this.scrollContainer).top + Utils.dom.height(_this.scrollContainer),
            elementBottom = Utils.dom.offset(_this.el).top + Utils.dom.height(_this.el);

        if (elementBottom < containerBottom) {
          _this.scrollContainer.removeEventListener('scroll', _this.scroll);
          handler(_this.el);
        }
      }, 50);

      this.scrollContainer.addEventListener('scroll', this.scroll);
      this.scroll();
    },
    unbind: function unbind() {
      this.scrollContainer.removeEventListener('scroll', this.scroll);
    }
  };

  var directiveScroll = {
    bind: function bind() {
      this.scrollContainer = this.el.closest('.layout-view');
      if (!this.scrollContainer) {
        this.scrollContainer = document.getElementById('quasar-app');
      }
    },
    update: function update(handler) {
      var _this = this;

      if (this.scroll) {
        this.scrollContainer.removeEventListener('scroll', this.scroll);
      }

      if (typeof handler !== 'function') {
        console.error('v-scroll requires a function as parameter', this.el);
        return;
      }

      this.scroll = function () {
        handler(_this.scrollContainer.scrollTop);
      };
      this.scrollContainer.addEventListener('scroll', this.scroll);
    },
    unbind: function unbind() {
      this.scrollContainer.removeEventListener('scroll', this.scroll);
    }
  };

  var directiveTooltip = {
    bind: function bind() {
      if (this.modifiers.wrap) {
        this.target = document.createElement('div');

        this.el.parentNode.insertBefore(this.target, this.el);
        this.target.appendChild(this.el);
      } else {
        this.target = this.el;
      }

      this.target.classList.add('quasar-tooltip');

      if (this.modifiers.inline) {
        this.target.classList.add('flex', 'inline');
      }
    },
    update: function update(value) {
      this.target.setAttribute('quasar-tooltip', value);
    }
  };

  var Checkbox = { template: "<label class=quasar-checkbox><input type=checkbox v-model=model><div></div></label>",
    props: {
      model: {
        type: Boolean,
        twoWay: true
      }
    }
  };

var   offset$1 = 20;
var   duration$1 = 100;
  function animate(menu, position, opening) {
    menu.style.display = 'block';

    var viewport = Utils.dom.viewport(),
        windowWidth = viewport.width,
        windowHeight = viewport.height,
        menuWidth = Utils.dom.width(menu),
        menuHeight = Utils.dom.height(menu),
        toRight = position.left + menuWidth < windowWidth || 2 * position.left < windowWidth,
        toBottom = position.top + menuHeight < windowHeight || 2 * position.top < windowHeight,
        css = {
      top: '',
      right: '',
      bottom: '',
      left: '',
      maxHeight: ''
    };

    if (toRight) {
      css.left = position.left + 'px';
    } else {
      css.left = Math.max(10, position.left - menuWidth) + 'px';
    }

    if (toBottom) {
      css.top = position.top + 'px';
      if (windowHeight - position.top < menuHeight) {
        css.maxHeight = windowHeight - position.top - offset$1 + 'px';
      }
    } else {
      css.top = Math.max(10, position.top - menuHeight) + 'px';
      if (position.top < menuHeight) {
        css.maxHeight = position.top - offset$1 + 'px';
      }
    }

    if (!opening) {
      toBottom = !toBottom;
    }

    Velocity(menu, 'stop');
    Utils.dom.css(menu, css);
    Velocity(menu, 'transition.slide' + (toBottom ? 'Down' : 'Up') + (opening ? 'In' : 'Out'), { duration: duration$1 });
  }

  var vm = {
    data: function data() {
      return {
        opened: false
      };
    },

    methods: {
      toggle: function toggle(event) {
        this[this.opened ? 'close' : 'open'](event);
      },
      open: function open(event) {
        var _this = this;

        event.preventDefault();

        if (this.opened) {
          return;
        }

        this.opened = true;
        this.$nextTick(function () {
          document.body.addEventListener('mousedown', _this.close);
          if (Platform.has.touch) {
            document.body.addEventListener('touchstart', _this.close);
          }
        });

        this.position = {
          top: event.clientY,
          left: event.clientX
        };

        animate(this.$els.menu, this.position, this.opened);
      },
      close: function close() {
        if (!this.opened) {
          return;
        }

        this.opened = false;
        document.body.removeEventListener('mousedown', this.close);
        if (Platform.has.touch) {
          document.body.removeEventListener('touchstart', this.close);
        }

        animate(this.$els.menu, this.position, this.opened);
      }
    }
  };

  var ContextMenu = { template: "<div v-el:menu=\"\" class=quasar-dropdown-menu style=\"display: none\"><slot></slot></div>",
    mixins: [vm],
    ready: function ready() {
      var _this = this;

      this.target = this.$el.parentNode;
      this.handler = function (event) {
        if (event.srcElement === _this.target) {
          _this.open(event);
        }
      };
      this.target.addEventListener('contextmenu', this.handler);
    },
    destroy: function destroy() {
      this.target.removeEventListener('contextmenu', this.handler);
      document.body.removeEventListener('mousedown', this.close);
    }
  };

  var drawerAnimationSpeed = 150;
  var backdropOpacity = {
    mat: 0.7,
    ios: 0.2
  };
  var leftDrawer = void 0;
  var rightDrawer = void 0;
  function getCurrentPosition(node) {
    var transform = Utils.dom.style(node, 'transform');
    return transform !== 'none' ? parseInt(transform.split(/[()]/)[1].split(', ')[4], 10) : 0;
  }

  function matToggleAnimate(onRightSide, opening, backdrop, percentage, drawerWidth, done, node) {
    var currentPosition = getCurrentPosition(node),
        closePosition = (onRightSide ? 1 : -1) * drawerWidth;

    Velocity(node, 'stop');
    Velocity(node, { translateX: opening ? [0, currentPosition] : [closePosition, currentPosition] }, { duration: !opening || currentPosition !== 0 ? drawerAnimationSpeed : 0 });

    if (opening) {
      backdrop.classList.add('active');
    }

    Velocity(backdrop, 'stop');
    Velocity(backdrop, {
      'backgroundColor': '#000',
      'backgroundColorAlpha': opening ? backdropOpacity.mat : 0.01
    }, {
      duration: drawerAnimationSpeed,
      complete: function complete() {
        if (!opening) {
          backdrop.classList.remove('active');
          window.removeEventListener('resize', closeDrawers);
        } else {
          window.addEventListener('resize', closeDrawers);
        }
        if (typeof done === 'function') {
          done();
        }
      }
    });
  }

  function iosToggleAnimate(onRightSide, opening, backdrop, percentage, drawerWidth, done) {
    if (opening) {
      backdrop.classList.add('active');
    }

    var currentPosition = getCurrentPosition(document.body),
        openPosition = (onRightSide ? -1 : 1) * drawerWidth;

    Velocity(document.body, 'stop');
    Velocity(document.body, { translateX: opening ? [openPosition, currentPosition] : [0, currentPosition] }, { duration: !opening || currentPosition !== openPosition ? drawerAnimationSpeed : 0 });

    Velocity(backdrop, 'stop');
    Velocity(backdrop, {
      'backgroundColor': '#000',
      'backgroundColorAlpha': opening ? backdropOpacity.ios : 0.01
    }, {
      duration: drawerAnimationSpeed,
      complete: function complete() {
        if (!opening) {
          backdrop.classList.remove('active');
          window.removeEventListener('resize', closeDrawers);
        } else {
          window.addEventListener('resize', closeDrawers);
        }
        if (typeof done === 'function') {
          done();
        }
      }
    });
  }

  function _openByTouch(event) {
    var content = this.$els.content,
        backdrop = this.$els.backdrop;

    if (Utils.dom.style(content, 'position') !== 'fixed') {
      return;
    }

    var position = Math.abs(event.deltaX),
        target = void 0,
        fn = void 0,
        percentage = void 0;

    if (event.isFinal) {
      this.opened = position > 75;
    }

    if (theme === 'ios') {
      position = Math.min(position, this.width);
      percentage = 1.0 - (this.width - Math.abs(position)) / this.width;
      fn = iosToggleAnimate;
      target = document.body;
      position = (this.rightSide ? -1 : 1) * position;
    } else {
      position = this.rightSide ? Math.max(this.width - position, 0) : Math.min(0, position - this.width);
      percentage = (this.width - Math.abs(position)) / this.width;
      fn = matToggleAnimate;
      target = content;
    }

    if (event.isFinal) {
      fn(this.rightSide, this.opened, backdrop, percentage, this.width, null, content);
      return;
    }

    target.style.transform = 'translateX(' + position + 'px)';
    backdrop.classList.add('active');
    backdrop.style.background = 'rgba(0,0,0,' + percentage * backdropOpacity[theme] + ')';
  }

  function getBetween(value, min, max) {
    if (value < min) {
      return min;
    }

    if (value > max) {
      return max;
    }

    return value;
  }

  function _closeByTouch(event) {
    var content = this.$els.content,
        backdrop = this.$els.backdrop;

    var target = void 0,
        fn = void 0,
        percentage = void 0,
        position = void 0,
        initialPosition = void 0;

    if (Utils.dom.style(content, 'position') !== 'fixed') {
      return;
    }

    position = this.rightSide ? getBetween(event.deltaX, 0, this.width) : getBetween(event.deltaX, -this.width, 0);
    initialPosition = (this.rightSide ? -1 : 1) * this.width;

    if (event.isFinal) {
      this.opened = Math.abs(position) <= 75;
    }

    if (theme === 'ios') {
      position = initialPosition + position;
      percentage = (this.rightSide ? -1 : 1) * position / this.width;
      fn = iosToggleAnimate;
      target = document.body;
    } else {
      percentage = 1 + (this.rightSide ? -1 : 1) * position / this.width;
      fn = matToggleAnimate;
      target = content;
    }

    if (event.isFinal) {
      fn(this.rightSide, this.opened, backdrop, percentage, this.width, null, content);
      return;
    }

    target.style.transform = 'translateX(' + position + 'px)';
    backdrop.style.background = 'rgba(0,0,0,' + percentage * backdropOpacity[theme] + ')';
  }

  function closeDrawers(done) {
    if (leftDrawer && leftDrawer.opened) {
      leftDrawer.setState(false, done);
      return;
    }
    if (rightDrawer && rightDrawer.opened) {
      rightDrawer.setState(false, done);
      return;
    }

    if (typeof done === 'function') {
      done();
    }
  }

  var Drawer = { template: "<div class=drawer :class=\"{'left-side': !rightSide, 'right-side': rightSide}\"><div class=\"drawer-opener touch-only mobile-only\" v-touch:pan=openByTouch v-touch-options:pan=\"{ direction: 'horizontal' }\" :class=\"{'fixed-left': !rightSide, 'fixed-right': rightSide}\">&nbsp;</div><div v-el:backdrop=\"\" class=\"drawer-backdrop fullscreen\" style=\"background: rgba(0, 0, 0, 0.01)\" @click=setState(false) v-touch:pan=closeByTouch v-touch-options:pan=\"{ direction: 'horizontal' }\"></div><div v-el:content=\"\" v-touch:pan=closeByTouch v-touch-options:pan=\"{ direction: 'horizontal' }\" class=\"drawer-content scroll\" :class=\"{'left-side': !rightSide, 'right-side': rightSide}\"><slot></slot></div></div>",
    props: {
      'right-side': {
        type: Boolean,
        default: false,
        coerce: Boolean
      },
      'swipe-only': {
        type: Boolean,
        default: false,
        coerce: Boolean
      }
    },
    data: function data() {
      return {
        opened: false
      };
    },

    methods: {
      openByTouch: function openByTouch(event) {
        _openByTouch.call(this, event);
      },
      closeByTouch: function closeByTouch(event) {
        _closeByTouch.call(this, event);
      },
      setState: function setState(state, done) {
        if (typeof state === 'boolean' && this.opened === state) {
          if (typeof done === 'function') {
            done();
          }
          return;
        }

        this.opened = !this.opened;
        var fn = theme === 'ios' ? iosToggleAnimate : matToggleAnimate;

        fn(this.rightSide, this.opened, this.$els.backdrop, this.opened ? 0.01 : 1, this.width, done, this.$els.content);
      }
    },
    ready: function ready() {
      var _this = this;

      var content = this.$els.content,
          toggles = this.$el.closest('.layout').getElementsByClassName((this.rightSide ? 'right' : 'left') + '-drawer-opener');

      this.width = Utils.dom.width(content);[].slice.call(toggles).forEach(function (el) {
        el.addEventListener('click', function () {
          _this.setState(true);
        });
      });[].slice.call(content.getElementsByClassName('drawer-closer')).forEach(function (el) {
        el.addEventListener('click', function () {
          _this.setState(false);
        });
      });

      if (this.swipeOnly) {
        [].slice.call(toggles).forEach(function (el) {
          el.classList.add('always-visible');
        });
        this.$el.classList.add('swipe-only');
      }

      if (this.rightSide) {
        rightDrawer = this;
      } else {
        leftDrawer = this;
      }
    },
    destroy: function destroy() {
      if (this.rightSide) {
        rightDrawer = null;
      } else {
        leftDrawer = null;
      }
    }
  };

  var DrawerLink = { template: "<div class=\"item item-link drawer-closer\"><i v-if=icon>{{icon}}</i><div class=\"item-content text-truncate\"><slot></slot></div></div>",
    props: ['icon']
  };

  var Dropdown = { template: "<div class=quasar-dropdown><div class=quasar-dropdown-target @click=toggle><slot name=target></slot></div><div v-el:menu=\"\" class=quasar-dropdown-menu style=\"display: none\"><slot></slot></div></div>",
    mixins: [vm],
    destroy: function destroy() {
      document.body.removeEventListener('mousedown', this.close);
    }
  };

  var Fab = { template: "<div class=\"quasar-fab flex inline justify-center\" :class=\"{opened: opened, 'with-backdrop': click || backdrop}\"><div v-if=\"click || backdrop\" class=backdrop @click=toggle(true)></div><button class=\"circular raised\" @click=toggle() :class=type><i class=quasar-fab-icon>{{icon}}</i> <i class=quasar-fab-active-icon>{{activeIcon}}</i></button><div class=\"quasar-fab-actions flex inline items-center\" :class=[direction]><slot></slot></div></div>",
    props: {
      type: {
        type: Array,
        default: function _default() {
          return ['primary'];
        },
        coerce: function coerce(value) {
          return Array.isArray(value) || typeof value === 'undefined' ? value : value.split(' ');
        }
      },
      icon: {
        type: String,
        default: 'add'
      },
      activeIcon: {
        type: String,
        default: 'close'
      },
      direction: {
        type: String,
        default: 'right'
      },
      click: {
        type: Function
      },
      backdrop: {
        type: Boolean,
        coerce: Boolean
      }
    },
    data: function data() {
      return {
        opened: false
      };
    },

    methods: {
      toggle: function toggle(fromBackdrop) {
        this.opened = !this.opened;

        if (!fromBackdrop && this.click && !this.opened) {
          this.click();
          return;
        }
      }
    },
    events: {
      closeFAB: function closeFAB() {
        this.toggle(true);
      }
    }
  };

  var SmallFab = { template: "<button class=\"circular small raised\" @click=closeFAB()><i><slot></slot></i></button>",
    methods: {
      closeFAB: function closeFAB() {
        this.$dispatch('closeFAB');
      }
    }
  };

  var Gallery = { template: "<div class=quasar-gallery><div v-for=\"img in src\" track-by=$index :style=\"{width: width}\"><img :src=img></div></div>",
    props: {
      src: {
        type: Array,
        required: true
      },
      width: {
        type: String,
        default: '150px'
      }
    }
  };

  var GallerySlider = { template: "<quasar-slider v-ref:slider=\"\" arrows=\"\" fullscreen=\"\" class=\"text-white bg-black quasar-gallery-slider\"><div v-for=\"img in src\" track-by=$index slot=slide class=\"no-padding flex items-center justify-center\"><div><img :src=img></div></div><i slot=action @click=toggleQuickView()>view_carousel</i><div class=quasar-gallery-slider-quickview :class=\"{active: quickView}\"><div v-for=\"img in src\" track-by=$index><img :src=img :class=\"{active: $refs.slider.slide === $index}\" @click=selectImage($index)></div></div></quasar-slider>",
    props: {
      src: {
        type: Array,
        required: true
      }
    },
    data: function data() {
      return {
        quickView: false
      };
    },

    methods: {
      toggleQuickView: function toggleQuickView() {
        this.quickView = !this.quickView;
      },
      selectImage: function selectImage(index) {
        this.$refs.slider.goToSlide(index, true);
        this.toggleQuickView();
      }
    }
  };

  var Grid = { template: "<quasar-grid-table v-ref:table=\"\" class=quasar-grid :data=\"data | gridShowSelected showOnlySelected selectionMode singleSelection | filterBy searchQuery\" :columns=columns :rows-per-page=rowsPerPage :sortable :selection-mode=selectionMode :selection-actions=selectionActions :no-data-label=noDataLabel :id-property=idProperty></quasar-grid-table>",
    props: {
      columns: {
        type: Array,
        required: true
      },
      data: {
        type: Array,
        required: true
      },
      rowsPerPage: {
        type: Number,
        default: 5
      },
      sortable: {
        type: Boolean,
        default: true,
        coerce: Boolean
      },
      noDataLabel: {
        type: String,
        default: 'No data to display.'
      },
      idProperty: String,
      selectionMode: {
        type: String,
        default: 'none',
        coerce: function coerce(value) {
          return value === 'single' || value === 'multiple' ? value : 'none';
        }
      },
      selectionActions: Array
    },
    data: function data() {
      return {
        searchQuery: '',
        showOnlySelected: false,
        singleSelection: []
      };
    },

    watch: {
      searchQuery: function searchQuery() {
        this.$refs.table.page = 1;
      },
      showOnlySelected: function showOnlySelected() {
        this.$refs.table.page = 1;
      }
    },
    events: {
      'toggle-selection': function toggleSelection() {
        this.showOnlySelected = !this.showOnlySelected;
      },
      filter: function filter(value) {
        this.searchQuery = value;
      },
      'set-single-selection': function setSingleSelection(value) {
        this.singleSelection = value;
      }
    }
  };

  var defaultRowsPerPage = [{ label: '5', value: 5 }, { label: '10', value: 10 }, { label: '15', value: 15 }, { label: '25', value: 25 }, { label: '50', value: 50 }, { label: '100', value: 100 }, { label: 'No pagination', value: 0 }];

  function getRowsPerPageOption(rowsPerPage) {
    if (defaultRowsPerPage.find(function (column) {
      return column.value === rowsPerPage;
    })) {
      return defaultRowsPerPage;
    }

    var options = defaultRowsPerPage.slice(0);

    options.unshift({
      label: '' + rowsPerPage,
      value: rowsPerPage
    });

    return options;
  }

  var GridTable = { template: "<div class=quasar-grid-table><div class=\"grid-top-controls sm-column gt-sm-row items-center justify-end\"><div class=\"auto sm-order-last self-center\"><div v-show=\"selectionMode !== 'none' &amp;&amp; controls === ''\" transition=slide>Selected {{selectedRows.length}} rows.</div><div v-show=\"selectionMode !== 'none' &amp;&amp; controls === 'selection'\" transition=slide><button :class=\"{disabled: selectedRows.length === 0}\" class=\"primary clear small\" @click=chooseAction()><i>menu</i></button> <button :class=\"{disabled: selectedRows.length === 0}\" class=\"primary clear small\" @click=clearSelection()><i>cancel</i></button><label><quasar-checkbox :model.sync=showOnlySelected></quasar-checkbox>Selected only</label></div><div v-show=\"controls === 'filter'\" transition=slide>Filter: <input v-model=searchQuery type=text :debounce=350> <button class=\"primary clear small\" @click=clearFilter()><i>clear</i></button></div></div><div class=row><button class=primary :class=\"{'clear': controls !== 'filter'}\" @click=\"toggleControls('filter')\"><i>search</i></button> <button v-if=\"selectionMode !== 'none'\" class=primary :class=\"{'clear': controls !== 'selection'}\" @click=\"toggleControls('selection')\"><i>playlist_add_check</i></button><quasar-select :model.sync=rowsPerPage :options=rowsPerPageOptions ok-label=Change cancel-label=Cancel title=\"Rows per Page\" fixed-label=\"<i>format_list_numbered</i>\"></quasar-select><quasar-select multiple :model.sync=chosenColumnsModel :options=chosenColumnsOptions ok-label=Select cancel-label=Cancel title=\"Visible Columns\" fixed-label=\"<i>view_column</i>\"></quasar-select></div></div><table class=\"striped highlight bordered compact\"><thead><tr><th v-if=\"selectionMode !== 'none'\" style=\"width: 30px text-align: center\">&nbsp;<th v-for=\"column in columns\" v-show=!column.hidden @click=sortBy(column.field) :class=\"{'sortable-column': sortable}\">{{{column.label}}} <i v-show=\"sortField === column.field &amp;&amp; sortOrder === -1\">keyboard_arrow_down</i> <i v-show=\"sortField === column.field &amp;&amp; sortOrder === 1\">keyboard_arrow_up</i><tbody><tr v-for=\"row in data | orderBy sortField sortOrder | limitBy computedRowsPerPage rowOffset\" :track-by=idProperty><td v-if=\"selectionMode !== 'none'\"><quasar-radio v-if=\"selectionMode === 'single'\" :model.sync=singleSelectedRow :value=row></quasar-radio><quasar-checkbox v-else=\"\" :model.sync=row.__selected></quasar-checkbox><td v-for=\"column in columns\" v-if=!column.hidden :style=column.style :class=column.classes :data-th=column.label>{{{column.formatter ? column.formatter(row[column.field]) : row[column.field]}}}<tfoot v-show=\"computedRowsPerPage > 10\"><tr><th v-if=\"selectionMode !== 'none'\">&nbsp;<th v-for=\"column in columns\" v-show=!column.hidden @click=sortBy(column.field) :class=\"{'sortable-column': sortable}\">{{{column.label}}} <i v-show=\"sortField === column.field &amp;&amp; sortOrder === -1\">keyboard_arrow_down</i> <i v-show=\"sortField === column.field &amp;&amp; sortOrder === 1\">keyboard_arrow_up</i></table><div class=\"grid-bottom-controls sm-column gt-sm-row items-center\"><div class=auto v-show=\"data.length > 0\">Showing {{rowOffset + 1}} to {{Math.min(rowsNumber, rowsPerPage * page)}} of {{rowsNumber}} entries</div><div class=auto v-else=\"\">{{noDataLabel}}</div><quasar-pagination :model.sync=page :max=pagesNumber v-show=\"rowsPerPage !== 0 &amp;&amp; rowsNumber > 0\"></quasar-pagination></div></div>",
    props: ['data', 'columns', 'rowsPerPage', 'sortable', 'noDataLabel', 'idProperty', 'selectionMode', 'selectionActions'],
    data: function data() {
      var rowsPerPage = this.rowsPerPage,
          chosenColumns = this.getChosenColumn();

      return {
        page: 1,
        rowsPerPageOptions: getRowsPerPageOption(rowsPerPage),
        sortField: '',
        sortOrder: 1,
        chosenColumnsModel: chosenColumns,
        singleSelectedRow: null,
        searchQuery: '',
        controls: '',
        showOnlySelected: false
      };
    },

    computed: {
      rowsNumber: function rowsNumber() {
        return this.data.length;
      },
      pagesNumber: function pagesNumber() {
        return Math.ceil(this.data.length / this.rowsPerPage);
      },
      chosenColumnsOptions: function chosenColumnsOptions() {
        return this.columns.map(function (column) {
          return {
            label: column.label,
            value: column.field
          };
        });
      },
      computedRowsPerPage: function computedRowsPerPage() {
        return this.rowsPerPage ? this.rowsPerPage : Infinity;
      },
      rowOffset: function rowOffset() {
        return this.rowsPerPage * (this.page - 1);
      },
      selectedRows: function selectedRows() {
        if (this.selectionMode === 'single') {
          return this.singleSelectedRow ? [this.singleSelectedRow] : [];
        }
        return this.data.filter(function (row) {
          return row.__selected === true;
        });
      },
      actionsModel: function actionsModel() {
        var index = -1;

        return this.selectionActions.map(function (item) {
          return {
            label: item.label,
            value: ++index
          };
        });
      }
    },
    watch: {
      rowsPerPage: function rowsPerPage(value) {
        this.page = 1;
      },
      chosenColumnsModel: function chosenColumnsModel(options) {
        for (var i = 0; i < this.columns.length; i++) {
          this.columns.$set(i, Utils.extend({}, this.columns[i], {
            hidden: !options.includes(this.columns[i].field)
          }));
        }
      },
      searchQuery: function searchQuery(value) {
        this.$dispatch('filter', value);
      },
      showOnlySelected: function showOnlySelected(value) {
        this.$dispatch('toggle-selection');
      },
      singleSelectedRow: function singleSelectedRow(value) {
        this.$dispatch('set-single-selection', [value]);
      }
    },
    methods: {
      goToPageByOffset: function goToPageByOffset(pageOffset) {
        this.page = Math.min(this.pagesNumber, Math.max(1, this.page + pageOffset));
      },
      sortBy: function sortBy(field) {
        if (!this.sortable) {
          return;
        }

        if (this.sortField !== field) {
          this.sortOrder = 1;
          this.sortField = field;
          return;
        }

        if (this.sortOrder === -1) {
          this.sortField = '';
        } else {
          this.sortOrder = -1;
        }
      },
      getChosenColumn: function getChosenColumn() {
        return this.columns.filter(function (column) {
          return column.hidden !== true;
        }).map(function (column) {
          return column.field;
        });
      },
      clearSelection: function clearSelection() {
        if (this.selectionMode === 'single') {
          this.singleSelectedRow = null;
        } else {
          this.data.forEach(function (row) {
            if (row.hasOwnProperty('__selected')) {
              row.__selected = false;
            }
          });
        }

        this.showOnlySelected = false;
      },
      clearFilter: function clearFilter() {
        this.searchQuery = '';
        this.controls = '';
      },
      toggleControls: function toggleControls(mode) {
        this.controls = this.controls === mode ? '' : mode;
      },
      chooseAction: function chooseAction() {
        var options = this.actionsModel,
            selectedRows = this.selectedRows,
            actions = this.selectionActions;

        if (selectedRows.length === 0) {
          return;
        }

        Dialog.create({
          title: 'Actions',
          message: 'Apply action for the ' + selectedRows.length + ' selected row(s).',
          radios: options,
          buttons: ['Cancel', {
            label: 'Apply',
            handler: function handler(data) {
              actions[data].handler(selectedRows);
            }
          }]
        }).show();
      }
    }
  };

  var InfiniteScroll = { template: "<div class=quasar-infinite-scroll><div v-el:content=\"\" class=quasar-infinite-scroll-content><slot></slot></div><br><div class=quasar-infinite-scroll-message v-show=refreshing><slot name=message></slot></div></div>",
    props: {
      handler: {
        type: Function,
        required: true
      },
      inline: {
        type: Boolean,
        default: false,
        coerce: Boolean
      }
    },
    data: function data() {
      return {
        index: 0,
        refreshing: false
      };
    },

    methods: {
      scroll: function scroll() {
        var _this = this;

        if (this.refreshing) {
          return;
        }

        var windowHeight = Utils.dom.height(this.scrollContainer),
            containerBottom = Utils.dom.offset(this.scrollContainer).top + windowHeight,
            triggerPosition = Utils.dom.offset(this.element).top + Utils.dom.height(this.element) - windowHeight;

        if (triggerPosition < containerBottom) {
          this.index++;
          this.refreshing = true;
          this.handler(this.index, function () {
            _this.refreshing = false;
            if (_this.element.closest('body')) {
              _this.scroll();
            }
          });
        }
      }
    },
    ready: function ready() {
      this.scroll = Utils.debounce(this.scroll, 50);
      this.element = this.$els.content;

      this.scrollContainer = this.inline ? this.$el : this.element.closest('.layout-view');
      if (!this.scrollContainer) {
        this.scrollContainer = document.getElementById('quasar-app');
      }
      this.scrollContainer.addEventListener('scroll', this.scroll);

      this.scroll();
    },
    destroy: function destroy() {
      this.scrollContainer.removeEventListener('scroll', this.scroll);
    }
  };

  var Layout = { template: "<div class=layout><div class=layout-header><slot name=header></slot></div><slot name=navigation></slot><div class=layout-content><slot></slot></div><div class=layout-footer><slot name=footer></slot></div></div>" };

  var ToolbarTitle = { template: "<div class=toolbar-content><div class=toolbar-title :class=\"['padding-' + padding]\"><div><slot></slot></div></div></div>",
    props: {
      padding: {
        type: Number,
        default: 1
      }
    }
  };

  var Numeric = { template: "<div class=\"quasar-numeric row inline items-center\"><i @click=increment(-1)>remove</i> <input type=text v-model=model class=quasar-input-field :style=\"{width: (''+model).length * 11 + 15 + 'px'}\" :debounce=debounce lazy=\"\" number=\"\"> <i @click=increment(1)>add</i></div>",
    props: {
      model: {
        type: Number,
        default: 0,
        coerce: function coerce(value) {
          return parseFloat(value, 10) || 0;
        }
      },
      step: {
        type: Number,
        default: 1,
        coerce: function coerce(value) {
          return parseFloat(value, 10);
        }
      },
      debounce: Number,
      min: Number,
      max: Number
    },
    watch: {
      model: function model(value) {
        if (typeof this.min === 'number' && value < this.min) {
          this.model = this.min;
        } else if (typeof this.max === 'number' && value > this.max) {
          this.model = this.max;
        }
      }
    },
    methods: {
      increment: function increment(direction) {
        this.model += direction * this.step;
      }
    }
  };

  var Pagination = { template: "<div class=quasar-pagination><button :class=\"{disabled: model === min}\" class=\"primary clear small circular\" @click=\"model = min\"><i>first_page</i></button> <button :class=\"{disabled: model === min}\" class=\"primary clear small circular\" @click=changeModelByOffset(-1)><i>keyboard_arrow_left</i></button> <input v-el:input=\"\" type=text v-model=newPage number=\"\" lazy=\"\" :style=\"{width: inputPlaceholder.length * 10 + 'px'}\" :placeholder=inputPlaceholder> <button :class=\"{disabled: model === max}\" class=\"primary clear small circular\" @click=changeModelByOffset(1)><i>keyboard_arrow_right</i></button> <button :class=\"{disabled: model === max}\" class=\"primary clear small circular\" @click=\"model = max\"><i>last_page</i></button></div>",
    props: {
      model: {
        type: Number,
        twoWay: true,
        required: true,
        coerce: function coerce(value) {
          return parseInt(value, 10);
        }
      },
      min: {
        type: Number,
        default: 1
      },
      max: {
        type: Number,
        required: true
      }
    },
    data: function data() {
      return {
        rangeMode: false,
        newPage: ''
      };
    },

    methods: {
      changeModelByOffset: function changeModelByOffset(offset) {
        this.model = this.normalize(this.model + offset);
      },
      normalize: function normalize(value) {
        return Math.min(this.max, Math.max(1, value));
      }
    },
    computed: {
      inputPlaceholder: function inputPlaceholder() {
        return this.model + ' / ' + this.max;
      }
    },
    watch: {
      newPage: function newPage(value) {
        var parsed = parseInt(value, 10);

        if (parsed) {
          this.model = this.normalize(parsed);
          this.$els.input.blur();
        }

        this.newPage = '';
      }
    }
  };

  var Parallax = { template: "<div class=\"quasar-parallax column items-center justify-center\" :style=\"{height: height + 'px'}\"><div class=quasar-parallax-image><img v-el:img=\"\" :src=src @load=processImage() :class=\"{ready: imageHasBeenLoaded}\" :style=\"{transform: 'translate3D(-50%,' + imageOffset + 'px, 0)'}\"></div><div class=quasar-parallax-text><slot name=loading v-if=!imageHasBeenLoaded></slot><slot v-else=\"\"></slot></div></div>",
    props: {
      src: {
        type: String,
        required: true
      },
      height: {
        type: Number,
        default: 500
      }
    },
    data: function data() {
      return {
        imageHasBeenLoaded: false,
        imageOffset: 0
      };
    },

    watch: {
      src: function src() {
        this.imageHasBeenLoaded = false;
      },
      height: function height() {
        this.updatePosition();
      }
    },
    methods: {
      processImage: function processImage() {
        this.imageHasBeenLoaded = true;
        this.processResize();
      },
      processResize: function processResize() {
        if (!this.imageHasBeenLoaded || !this.pageContainer) {
          return;
        }

        this.image.style.minHeight = Math.max(this.height, Utils.dom.height(this.pageContainer)) + 'px';
        this.imageHeight = Utils.dom.height(this.image);

        this.updatePosition();
      },
      updatePosition: function updatePosition() {
        if (!this.imageHasBeenLoaded) {
          return;
        }

        var containerTop = Utils.dom.offset(this.pageContainer).top,
            containerHeight = Utils.dom.height(this.pageContainer),
            containerBottom = containerTop + containerHeight,
            top = Utils.dom.offset(this.container).top,
            bottom = top + this.height;

        if (bottom > containerTop && top < containerBottom) {
          this.imageOffset = Math.round(containerTop - top + (containerHeight - this.imageHeight) / 2);
        }
      }
    },
    ready: function ready() {
      this.container = this.$el;
      this.image = this.$els.img;

      this.pageContainer = this.$el.closest('.layout-view');
      if (!this.pageContainer) {
        this.pageContainer = document.getElementById('quasar-app');
      }
      this.resizeHandler = Utils.debounce(this.processResize, 50);

      window.addEventListener('resize', this.resizeHandler);
      this.pageContainer.addEventListener('scroll', this.updatePosition);
      this.processResize();
    },
    beforeDestroy: function beforeDestroy() {
      window.removeEventListener('resize', this.resizeHandler);
      this.pageContainer.removeEventListener('scroll', this.updatePosition);
    }
  };

  var Progress = { template: "<div class=quasar-progress><div :style=\"{width: model + '%'}\"></div></div>",
    props: {
      model: {
        type: Number,
        default: 0
      }
    }
  };

  var PullToRefresh = { template: "<div class=pull-to-refresh><div class=pull-to-refresh-container :style=\"{transform: 'translateY(' + pullPosition + 'px)'}\" v-touch:pan=pull v-touch-options:pan=\"{ direction: 'vertical' }\"><div class=\"pull-to-refresh-message row items-center justify-center\"><i v-show=\"state !== 'refreshing'\" :class=\"{'rotate-180': state === 'pulled'}\">arrow_downward</i> <i v-else=\"\" class=spin>{{refreshIcon}}</i> &nbsp;&nbsp; <span v-show=\"state === 'pull'\">{{pullMessage}} </span><span v-show=\"state === 'pulled'\">{{releaseMessage}} </span><span v-show=\"state === 'refreshing'\">{{refreshMessage}}</span></div><slot></slot></div></div>",
    props: {
      handler: {
        type: Function,
        required: true
      },
      distance: {
        type: Number,
        default: 35
      },
      pullMessage: {
        type: String,
        default: 'Pull down to refresh'
      },
      releaseMessage: {
        type: String,
        default: 'Release to refresh'
      },
      refreshMessage: {
        type: String,
        default: 'Refreshing...'
      },
      refreshIcon: {
        type: String,
        default: 'refresh'
      }
    },
    data: function data() {
      var height = 65;

      return {
        state: 'pull',
        pullPosition: -height,
        height: height,
        animating: false,
        pulling: false,
        scrolling: false
      };
    },

    methods: {
      pull: function pull(hammer) {
        if (this.scrolling) {
          if (hammer.isFinal) {
            this.scrolling = false;
          }
          return;
        }
        if (this.animating) {
          return;
        }

        if (!this.pulling) {
          if (this.state === 'refreshing') {
            return;
          }
          if (this.pullPosition === -this.height && hammer.direction === Hammer.DIRECTION_UP) {
            return;
          }

          var containerTop = Utils.dom.offset(this.scrollContainer).top,
              thisContainerTop = Utils.dom.offset(this.$el).top;

          if (containerTop > thisContainerTop) {
            this.scrolling = true;
            return;
          }

          this.originalScrollOverflow = this.scrollContainer.style.overflow;
          this.scrollContainer.style.overflow = 'hidden';
        }

        this.pulling = true;
        this.pullPosition = -this.height + Math.max(0, Math.pow(hammer.deltaY, 0.85));

        if (this.pullPosition > this.distance) {
          if (hammer.isFinal) {
            this.state = 'refreshing';
            this.pulling = false;
            this.scrollContainer.style.overflow = this.originalScrollOverflow;
            this.animateTo(0);
            this.trigger();
          } else {
            this.state = 'pulled';
          }
        } else {
          this.state = 'pull';
          if (hammer.isFinal) {
            this.pulling = false;
            this.scrollContainer.style.overflow = this.originalScrollOverflow;
            this.animateTo(-this.height);
          }
        }
      },
      animateTo: function animateTo(target, done, previousCall) {
        var _this = this;

        if (!previousCall && this.animationId) {
          cancelAnimationFrame(this.animating);
        }

        this.pullPosition -= (this.pullPosition - target) / 7;

        if (this.pullPosition - target > 1) {
          this.animating = requestAnimationFrame(function () {
            _this.animateTo(target, done, true);
          });
        } else {
          this.animating = requestAnimationFrame(function () {
            _this.pullPosition = target;
            _this.animating = false;
            done && done();
          });
        }
      },
      trigger: function trigger() {
        var _this2 = this;

        this.handler(function () {
          _this2.animateTo(-_this2.height, function () {
            _this2.state = 'pull';
          });
        });
      }
    },
    ready: function ready() {
      this.scrollContainer = this.$el.parentNode;
    }
  };

  var Radio = { template: "<label class=quasar-radio><input type=radio v-model=model :value=value><div></div></label>",
    props: {
      model: {
        twoWay: true,
        required: true
      },
      value: {
        required: true
      }
    }
  };

  function modelToPosition(model, min, max, size) {
    return (model - min) / (max - min) * 100 + '%';
  }

  var Range = { template: "<div class=\"quasar-range non-selectable\" :class=\"{active: active}\" v-touch:pan=pan v-touch-options:pan=\"{ direction: 'horizontal' }\"><div class=quasar-range-container><div class=quasar-range-thumb :style=\"{left: position}\"></div></div></div>",
    props: {
      model: {
        type: Number,
        twoWay: true,
        required: true,
        coerce: function coerce(value) {
          return parseInt(value, 10);
        }
      },
      min: {
        type: Number,
        required: true,
        coerce: function coerce(value) {
          return parseInt(value, 10);
        }
      },
      max: {
        type: Number,
        required: true,
        coerce: function coerce(value) {
          return parseInt(value, 10);
        }
      },
      precision: {
        type: Number,
        coerce: function coerce(value) {
          return parseInt(value, 10);
        }
      }
    },
    data: function data() {
      return {
        position: 0,
        active: false
      };
    },

    methods: {
      pan: function pan(event) {
        var size = this.$el.offsetWidth,
            range = this.max - this.min,
            value = (this.model - this.min) / range,
            percentage = Math.min(1, Math.max(0, value + event.deltaX / size)),
            newValue = (this.min + percentage * range).toFixed(this.precision);

        if (event.isFinal) {
          this.model = parseFloat(newValue, 10);
          this.active = false;
          return;
        }

        this.position = modelToPosition(newValue, this.min, this.max, size);
        this.active = true;
      },
      update: function update() {
        this.position = modelToPosition(this.model, this.min, this.max, this.$el.offsetWidth);
      }
    },
    watch: {
      model: function model(value) {
        this.$nextTick(this.update);
      },
      min: function min(value) {
        if (this.model < value) {
          this.model = value;
          return;
        }
        this.$nextTick(this.update);
      },
      max: function max(value) {
        if (this.model > value) {
          this.model = value;
          return;
        }
        this.$nextTick(this.update);
      }
    },
    ready: function ready() {
      var _this = this;

      this.update = debounce(this.update, 50);
      this.update();

      this.clickHandler = function (event) {
        if (Platform.has.touch && event.eventPhase === Event.BUBBLING_PHASE) {
          return;
        }

        var range = _this.max - _this.min,
            percentage = Math.min(1, Math.max(0, event.offsetX / _this.$el.offsetWidth));

        _this.model = parseFloat((_this.min + percentage * range).toFixed(_this.precision), 10);
      };

      this.$el.addEventListener('click', this.clickHandler);
    },
    destroy: function destroy() {
      this.$el.removeEventListener('click', this.clickHandler);
    }
  };

  var Rating = { template: "<div class=quasar-rating><i v-for=\"index in maxGrade\" :class=\"{active: (!mouseModel &amp;&amp; model > index) || (mouseModel &amp;&amp; mouseModel > index)}\" @click=\"model = index + 1\" @mouseover=\"mouseModel = index + 1\" @mouseout=\"mouseModel = 0\">{{icon}}</i></div>",
    props: {
      model: {
        type: Number,
        default: 0,
        required: true
      },
      maxGrade: {
        type: Number,
        required: true
      },
      icon: {
        type: String,
        default: 'grade'
      }
    },
    data: function data() {
      return {
        mouseModel: 0
      };
    }
  };

  var Search = { template: "<div class=quasar-search :class=\"{'quasar-search-centered': !this.focused &amp;&amp; this.model === ''}\"><div class=quasar-search-input-container><button class=quasar-search-icon><i>search</i></button> <input type=text class=\"quasar-search-input no-style\" placeholder=Search v-model=model :debounce=debounce @focus=\"focused = true\" @blur=\"focused = false\"> <button class=quasar-search-clear @click=clear() :class=\"{hidden: this.model === ''}\"><i class=mat-only>clear</i> <i class=ios-only>cancel</i></button></div></div>",
    props: {
      model: {
        type: String,
        default: ''
      },
      debounce: {
        type: Number,
        default: 300
      }
    },
    data: function data() {
      return {
        focused: false
      };
    },

    methods: {
      clear: function clear() {
        this.model = '';
      }
    }
  };

  var Select = { template: "<button class=\"primary clear\" @click=pick>{{{fixedLabel || label}}} ⇣</button>",
    props: {
      model: {
        required: true
      },
      options: {
        type: Array,
        required: true,
        validator: function validator(options) {
          return !options.some(function (option) {
            return typeof option.label === 'undefined' || typeof option.value === 'undefined';
          });
        }
      },
      multiple: {
        type: Boolean,
        coerce: Boolean
      },
      okLabel: {
        type: String,
        default: 'OK'
      },
      cancelLabel: {
        type: String,
        default: 'Cancel'
      },
      title: {
        type: String,
        default: 'Select'
      },
      message: String,
      fixedLabel: String
    },
    computed: {
      label: function label() {
        return this.multiple ? this.getMultipleLabel() : this.getSingleLabel();
      }
    },
    methods: {
      getSingleLabel: function getSingleLabel() {
        var _this = this;

        var option = this.options.find(function (option) {
          return option.value === _this.model;
        });
        return option ? option.label : 'Select';
      },
      getMultipleLabel: function getMultipleLabel() {
        var _this2 = this;

        var options = this.options.filter(function (option) {
          return _this2.model.includes(option.value);
        }).map(function (option) {
          return option.label;
        });

        if (options.length === 0) {
          return 'Select';
        } else if (options.length > 1) {
          return options[0] + ', ...';
        }
        return options[0];
      },
      mapSingle: function mapSingle(option) {
        option.selected = option.value === this.model;
        return option;
      },
      mapMultiple: function mapMultiple(option) {
        option.checked = this.model.includes(option.value);
        return option;
      },
      pick: function pick() {
        var self = this,
            mapHandler = this.multiple ? this.mapMultiple : this.mapSingle,
            options = this.options.map(mapHandler.bind(this)),
            config = {
          title: self.title,
          message: self.message,
          buttons: [self.cancelLabel, {
            label: self.okLabel,
            handler: function handler(data) {
              self.model = data;
            }
          }]
        };

        config[this.multiple ? 'checkboxes' : 'radios'] = options;

        Dialog.create(config).show();
      }
    }
  };

  var Slider = { template: "<div class=quasar-slider :class=\"{fullscreen: inFullscreen}\"><div class=quasar-slider-inner><div v-el:track=\"\" class=quasar-slider-track :class=\"{'with-arrows': arrows, 'with-toolbar': toolbar}\" v-touch:pan=pan v-touch-options:pan=\"{ direction: 'horizontal' }\"><slot name=slide></slot></div><div v-if=arrows class=\"quasar-slider-left-button row items-center justify-center\" :class=\"{hidden: slide === 0}\"><i @click=\"goToSlide(slide - 1)\">keyboard_arrow_left</i></div><div v-if=arrows class=\"quasar-slider-right-button row items-center justify-center\" :class=\"{hidden: slide === slidesNumber - 1}\" @click=\"goToSlide(slide + 1)\"><i>keyboard_arrow_right</i></div><div v-if=toolbar class=\"quasar-slider-toolbar row items-center justify-end\"><div class=\"quasar-slider-dots auto row items-center justify-center\"><i v-if=dots v-for=\"n in slidesNumber\" @click=goToSlide(n)><span v-show=\"n !== slide\">panorama_fish_eye</span> <span v-else=\"\">lens</span></i></div><div class=\"row items-center\"><slot name=action></slot><i v-if=fullscreen @click=toggleFullscreen()><span v-show=!inFullscreen>fullscreen</span> <span v-else=\"\">fullscreen_exit</span></i></div></div><slot></slot></div></div>",
    props: {
      arrows: {
        type: Boolean,
        default: false,
        coerce: Boolean
      },
      dots: {
        type: Boolean,
        default: false,
        coerce: Boolean
      },
      fullscreen: {
        type: Boolean,
        default: false,
        coerce: Boolean
      },
      actions: {
        type: Boolean,
        default: false,
        coerce: Boolean
      }
    },
    data: function data() {
      return {
        position: 0,
        slide: 0,
        slidesNumber: 0,
        inFullscreen: false
      };
    },

    computed: {
      toolbar: function toolbar() {
        return this.dots || this.fullscreen || this.actions;
      }
    },
    methods: {
      pan: function pan(event) {
        if (!this.hasOwnProperty('initialPosition')) {
          this.initialPosition = this.position;
          Velocity(this.$els.track, 'stop');
        }

        var delta = event.deltaX;

        if (this.slide === 0 && event.deltaX > 0 || this.slide === this.slidesNumber - 1 && event.deltaX < 0) {
          delta = delta / 10;
        }

        this.position = this.initialPosition + delta / this.$els.track.offsetWidth * 100;
        this.$els.track.style.transform = 'translateX(' + this.position + '%)';

        if (event.isFinal) {
          if (event.distance < 100) {
            this.goToSlide(this.slide);
          } else {
            this.goToSlide(event.deltaX < 0 ? this.slide + 1 : this.slide - 1);
          }
          delete this.initialPosition;
        }
      },
      goToSlide: function goToSlide(slide, noAnimation) {
        this.slide = Math.min(this.slidesNumber - 1, Math.max(0, slide));

        Velocity(this.$els.track, 'stop');
        Velocity(this.$els.track, {
          translateX: [-this.slide * 100 + '%', this.position + '%']
        }, noAnimation ? { duration: 0 } : undefined);

        this.position = -this.slide * 100;
      },
      toggleFullscreen: function toggleFullscreen() {
        this.inFullscreen = !this.inFullscreen;
      }
    },
    ready: function ready() {
      this.slidesNumber = this.$els.track.children.length;
    }
  };

  var audio = "<svg class=\"quasar-spinner\" :fill=\"color\" :width=\"size\" :height=\"size\" viewBox=\"0 0 55 80\" xmlns=\"http://www.w3.org/2000/svg\"><g transform=\"matrix(1 0 0 -1 0 80)\"><rect width=\"10\" height=\"20\" rx=\"3\"><animate attributeName=\"height\" begin=\"0s\" dur=\"4.3s\" values=\"20;45;57;80;64;32;66;45;64;23;66;13;64;56;34;34;2;23;76;79;20\" calcMode=\"linear\" repeatCount=\"indefinite\"/></rect><rect x=\"15\" width=\"10\" height=\"80\" rx=\"3\"><animate attributeName=\"height\" begin=\"0s\" dur=\"2s\" values=\"80;55;33;5;75;23;73;33;12;14;60;80\" calcMode=\"linear\" repeatCount=\"indefinite\"/></rect><rect x=\"30\" width=\"10\" height=\"50\" rx=\"3\"><animate attributeName=\"height\" begin=\"0s\" dur=\"1.4s\" values=\"50;34;78;23;56;23;34;76;80;54;21;50\" calcMode=\"linear\" repeatCount=\"indefinite\"/></rect><rect x=\"45\" width=\"10\" height=\"30\" rx=\"3\"><animate attributeName=\"height\" begin=\"0s\" dur=\"2s\" values=\"30;45;13;80;56;72;45;76;34;23;67;30\" calcMode=\"linear\" repeatCount=\"indefinite\"/></rect></g></svg>\n";

  var ball = "<svg class=\"quasar-spinner\" :stroke=\"color\" :width=\"size\" :height=\"size\" viewBox=\"0 0 57 57\" xmlns=\"http://www.w3.org/2000/svg\"><g transform=\"translate(1 1)\" stroke-width=\"2\" fill=\"none\" fill-rule=\"evenodd\"><circle cx=\"5\" cy=\"50\" r=\"5\"><animate attributeName=\"cy\" begin=\"0s\" dur=\"2.2s\" values=\"50;5;50;50\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"cx\" begin=\"0s\" dur=\"2.2s\" values=\"5;27;49;5\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"27\" cy=\"5\" r=\"5\"><animate attributeName=\"cy\" begin=\"0s\" dur=\"2.2s\" from=\"5\" to=\"5\" values=\"5;50;50;5\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"cx\" begin=\"0s\" dur=\"2.2s\" from=\"27\" to=\"27\" values=\"27;49;5;27\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"49\" cy=\"50\" r=\"5\"><animate attributeName=\"cy\" begin=\"0s\" dur=\"2.2s\" values=\"50;50;5;50\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"cx\" from=\"49\" to=\"49\" begin=\"0s\" dur=\"2.2s\" values=\"49;5;27;49\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle></g></svg>\n";

  var bars = "<svg class=\"quasar-spinner\" :fill=\"color\" :width=\"size\" :height=\"size\" viewBox=\"0 0 135 140\" xmlns=\"http://www.w3.org/2000/svg\"><rect y=\"10\" width=\"15\" height=\"120\" rx=\"6\"><animate attributeName=\"height\" begin=\"0.5s\" dur=\"1s\" values=\"120;110;100;90;80;70;60;50;40;140;120\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"y\" begin=\"0.5s\" dur=\"1s\" values=\"10;15;20;25;30;35;40;45;50;0;10\" calcMode=\"linear\" repeatCount=\"indefinite\"/></rect><rect x=\"30\" y=\"10\" width=\"15\" height=\"120\" rx=\"6\"><animate attributeName=\"height\" begin=\"0.25s\" dur=\"1s\" values=\"120;110;100;90;80;70;60;50;40;140;120\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"y\" begin=\"0.25s\" dur=\"1s\" values=\"10;15;20;25;30;35;40;45;50;0;10\" calcMode=\"linear\" repeatCount=\"indefinite\"/></rect><rect x=\"60\" width=\"15\" height=\"140\" rx=\"6\"><animate attributeName=\"height\" begin=\"0s\" dur=\"1s\" values=\"120;110;100;90;80;70;60;50;40;140;120\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"y\" begin=\"0s\" dur=\"1s\" values=\"10;15;20;25;30;35;40;45;50;0;10\" calcMode=\"linear\" repeatCount=\"indefinite\"/></rect><rect x=\"90\" y=\"10\" width=\"15\" height=\"120\" rx=\"6\"><animate attributeName=\"height\" begin=\"0.25s\" dur=\"1s\" values=\"120;110;100;90;80;70;60;50;40;140;120\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"y\" begin=\"0.25s\" dur=\"1s\" values=\"10;15;20;25;30;35;40;45;50;0;10\" calcMode=\"linear\" repeatCount=\"indefinite\"/></rect><rect x=\"120\" y=\"10\" width=\"15\" height=\"120\" rx=\"6\"><animate attributeName=\"height\" begin=\"0.5s\" dur=\"1s\" values=\"120;110;100;90;80;70;60;50;40;140;120\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"y\" begin=\"0.5s\" dur=\"1s\" values=\"10;15;20;25;30;35;40;45;50;0;10\" calcMode=\"linear\" repeatCount=\"indefinite\"/></rect></svg>\n";

  var circles = "<svg class=\"quasar-spinner\" :fill=\"color\" :width=\"size\" :height=\"size\" viewBox=\"0 0 135 135\" xmlns=\"http://www.w3.org/2000/svg\"><path d=\"M67.447 58c5.523 0 10-4.477 10-10s-4.477-10-10-10-10 4.477-10 10 4.477 10 10 10zm9.448 9.447c0 5.523 4.477 10 10 10 5.522 0 10-4.477 10-10s-4.478-10-10-10c-5.523 0-10 4.477-10 10zm-9.448 9.448c-5.523 0-10 4.477-10 10 0 5.522 4.477 10 10 10s10-4.478 10-10c0-5.523-4.477-10-10-10zM58 67.447c0-5.523-4.477-10-10-10s-10 4.477-10 10 4.477 10 10 10 10-4.477 10-10z\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 67 67\" to=\"-360 67 67\" dur=\"2.5s\" repeatCount=\"indefinite\"/></path><path d=\"M28.19 40.31c6.627 0 12-5.374 12-12 0-6.628-5.373-12-12-12-6.628 0-12 5.372-12 12 0 6.626 5.372 12 12 12zm30.72-19.825c4.686 4.687 12.284 4.687 16.97 0 4.686-4.686 4.686-12.284 0-16.97-4.686-4.687-12.284-4.687-16.97 0-4.687 4.686-4.687 12.284 0 16.97zm35.74 7.705c0 6.627 5.37 12 12 12 6.626 0 12-5.373 12-12 0-6.628-5.374-12-12-12-6.63 0-12 5.372-12 12zm19.822 30.72c-4.686 4.686-4.686 12.284 0 16.97 4.687 4.686 12.285 4.686 16.97 0 4.687-4.686 4.687-12.284 0-16.97-4.685-4.687-12.283-4.687-16.97 0zm-7.704 35.74c-6.627 0-12 5.37-12 12 0 6.626 5.373 12 12 12s12-5.374 12-12c0-6.63-5.373-12-12-12zm-30.72 19.822c-4.686-4.686-12.284-4.686-16.97 0-4.686 4.687-4.686 12.285 0 16.97 4.686 4.687 12.284 4.687 16.97 0 4.687-4.685 4.687-12.283 0-16.97zm-35.74-7.704c0-6.627-5.372-12-12-12-6.626 0-12 5.373-12 12s5.374 12 12 12c6.628 0 12-5.373 12-12zm-19.823-30.72c4.687-4.686 4.687-12.284 0-16.97-4.686-4.686-12.284-4.686-16.97 0-4.687 4.686-4.687 12.284 0 16.97 4.686 4.687 12.284 4.687 16.97 0z\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 67 67\" to=\"360 67 67\" dur=\"8s\" repeatCount=\"indefinite\"/></path></svg>\n";

  var dots = "<svg class=\"quasar-spinner\" :fill=\"color\" :width=\"size\" :height=\"size\" viewBox=\"0 0 120 30\" xmlns=\"http://www.w3.org/2000/svg\"><circle cx=\"15\" cy=\"15\" r=\"15\"><animate attributeName=\"r\" from=\"15\" to=\"15\" begin=\"0s\" dur=\"0.8s\" values=\"15;9;15\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"fill-opacity\" from=\"1\" to=\"1\" begin=\"0s\" dur=\"0.8s\" values=\"1;.5;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"60\" cy=\"15\" r=\"9\" fill-opacity=\".3\"><animate attributeName=\"r\" from=\"9\" to=\"9\" begin=\"0s\" dur=\"0.8s\" values=\"9;15;9\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"fill-opacity\" from=\".5\" to=\".5\" begin=\"0s\" dur=\"0.8s\" values=\".5;1;.5\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"105\" cy=\"15\" r=\"15\"><animate attributeName=\"r\" from=\"15\" to=\"15\" begin=\"0s\" dur=\"0.8s\" values=\"15;9;15\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"fill-opacity\" from=\"1\" to=\"1\" begin=\"0s\" dur=\"0.8s\" values=\"1;.5;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle></svg>\n";

  var facebook = "<svg class=\"quasar-spinner\" :width=\"size\" :height=\"size\" viewBox=\"0 0 100 100\" xmlns=\"http://www.w3.org/2000/svg\" preserveAspectRatio=\"xMidYMid\"><g transform=\"translate(20 50)\"><rect x=\"-10\" y=\"-30\" width=\"20\" height=\"60\" :fill=\"color\" opacity=\"0.6\"><animateTransform attributeName=\"transform\" type=\"scale\" from=\"2\" to=\"1\" begin=\"0s\" repeatCount=\"indefinite\" dur=\"1s\" calcMode=\"spline\" keySplines=\"0.1 0.9 0.4 1\" keyTimes=\"0;1\" values=\"2;1\"></animateTransform></rect></g><g transform=\"translate(50 50)\"><rect x=\"-10\" y=\"-30\" width=\"20\" height=\"60\" :fill=\"color\" opacity=\"0.8\"><animateTransform attributeName=\"transform\" type=\"scale\" from=\"2\" to=\"1\" begin=\"0.1s\" repeatCount=\"indefinite\" dur=\"1s\" calcMode=\"spline\" keySplines=\"0.1 0.9 0.4 1\" keyTimes=\"0;1\" values=\"2;1\"></animateTransform></rect></g><g transform=\"translate(80 50)\"><rect x=\"-10\" y=\"-30\" width=\"20\" height=\"60\" :fill=\"color\" opacity=\"0.9\"><animateTransform attributeName=\"transform\" type=\"scale\" from=\"2\" to=\"1\" begin=\"0.2s\" repeatCount=\"indefinite\" dur=\"1s\" calcMode=\"spline\" keySplines=\"0.1 0.9 0.4 1\" keyTimes=\"0;1\" values=\"2;1\"></animateTransform></rect></g></svg>\n";

  var gears = "<svg class=\"quasar-spinner\" :width=\"size\" :height=\"size\" viewBox=\"0 0 100 100\" preserveAspectRatio=\"xMidYMid\" xmlns=\"http://www.w3.org/2000/svg\"><g transform=\"translate(-20,-20)\"><path d=\"M79.9,52.6C80,51.8,80,50.9,80,50s0-1.8-0.1-2.6l-5.1-0.4c-0.3-2.4-0.9-4.6-1.8-6.7l4.2-2.9c-0.7-1.6-1.6-3.1-2.6-4.5 L70,35c-1.4-1.9-3.1-3.5-4.9-4.9l2.2-4.6c-1.4-1-2.9-1.9-4.5-2.6L59.8,27c-2.1-0.9-4.4-1.5-6.7-1.8l-0.4-5.1C51.8,20,50.9,20,50,20 s-1.8,0-2.6,0.1l-0.4,5.1c-2.4,0.3-4.6,0.9-6.7,1.8l-2.9-4.1c-1.6,0.7-3.1,1.6-4.5,2.6l2.1,4.6c-1.9,1.4-3.5,3.1-5,4.9l-4.5-2.1 c-1,1.4-1.9,2.9-2.6,4.5l4.1,2.9c-0.9,2.1-1.5,4.4-1.8,6.8l-5,0.4C20,48.2,20,49.1,20,50s0,1.8,0.1,2.6l5,0.4 c0.3,2.4,0.9,4.7,1.8,6.8l-4.1,2.9c0.7,1.6,1.6,3.1,2.6,4.5l4.5-2.1c1.4,1.9,3.1,3.5,5,4.9l-2.1,4.6c1.4,1,2.9,1.9,4.5,2.6l2.9-4.1 c2.1,0.9,4.4,1.5,6.7,1.8l0.4,5.1C48.2,80,49.1,80,50,80s1.8,0,2.6-0.1l0.4-5.1c2.3-0.3,4.6-0.9,6.7-1.8l2.9,4.2 c1.6-0.7,3.1-1.6,4.5-2.6L65,69.9c1.9-1.4,3.5-3,4.9-4.9l4.6,2.2c1-1.4,1.9-2.9,2.6-4.5L73,59.8c0.9-2.1,1.5-4.4,1.8-6.7L79.9,52.6 z M50,65c-8.3,0-15-6.7-15-15c0-8.3,6.7-15,15-15s15,6.7,15,15C65,58.3,58.3,65,50,65z\" :fill=\"color\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"90 50 50\" to=\"0 50 50\" dur=\"1s\" repeatCount=\"indefinite\"></animateTransform></path></g><g transform=\"translate(20,20) rotate(15 50 50)\"><path d=\"M79.9,52.6C80,51.8,80,50.9,80,50s0-1.8-0.1-2.6l-5.1-0.4c-0.3-2.4-0.9-4.6-1.8-6.7l4.2-2.9c-0.7-1.6-1.6-3.1-2.6-4.5 L70,35c-1.4-1.9-3.1-3.5-4.9-4.9l2.2-4.6c-1.4-1-2.9-1.9-4.5-2.6L59.8,27c-2.1-0.9-4.4-1.5-6.7-1.8l-0.4-5.1C51.8,20,50.9,20,50,20 s-1.8,0-2.6,0.1l-0.4,5.1c-2.4,0.3-4.6,0.9-6.7,1.8l-2.9-4.1c-1.6,0.7-3.1,1.6-4.5,2.6l2.1,4.6c-1.9,1.4-3.5,3.1-5,4.9l-4.5-2.1 c-1,1.4-1.9,2.9-2.6,4.5l4.1,2.9c-0.9,2.1-1.5,4.4-1.8,6.8l-5,0.4C20,48.2,20,49.1,20,50s0,1.8,0.1,2.6l5,0.4 c0.3,2.4,0.9,4.7,1.8,6.8l-4.1,2.9c0.7,1.6,1.6,3.1,2.6,4.5l4.5-2.1c1.4,1.9,3.1,3.5,5,4.9l-2.1,4.6c1.4,1,2.9,1.9,4.5,2.6l2.9-4.1 c2.1,0.9,4.4,1.5,6.7,1.8l0.4,5.1C48.2,80,49.1,80,50,80s1.8,0,2.6-0.1l0.4-5.1c2.3-0.3,4.6-0.9,6.7-1.8l2.9,4.2 c1.6-0.7,3.1-1.6,4.5-2.6L65,69.9c1.9-1.4,3.5-3,4.9-4.9l4.6,2.2c1-1.4,1.9-2.9,2.6-4.5L73,59.8c0.9-2.1,1.5-4.4,1.8-6.7L79.9,52.6 z M50,65c-8.3,0-15-6.7-15-15c0-8.3,6.7-15,15-15s15,6.7,15,15C65,58.3,58.3,65,50,65z\" :fill=\"color\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 50 50\" to=\"90 50 50\" dur=\"1s\" repeatCount=\"indefinite\"></animateTransform></path></g></svg>\n";

  var grid = "<svg class=\"quasar-spinner\" :fill=\"color\" :width=\"size\" :height=\"size\" viewBox=\"0 0 105 105\" xmlns=\"http://www.w3.org/2000/svg\"><circle cx=\"12.5\" cy=\"12.5\" r=\"12.5\"><animate attributeName=\"fill-opacity\" begin=\"0s\" dur=\"1s\" values=\"1;.2;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"12.5\" cy=\"52.5\" r=\"12.5\" fill-opacity=\".5\"><animate attributeName=\"fill-opacity\" begin=\"100ms\" dur=\"1s\" values=\"1;.2;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"52.5\" cy=\"12.5\" r=\"12.5\"><animate attributeName=\"fill-opacity\" begin=\"300ms\" dur=\"1s\" values=\"1;.2;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"52.5\" cy=\"52.5\" r=\"12.5\"><animate attributeName=\"fill-opacity\" begin=\"600ms\" dur=\"1s\" values=\"1;.2;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"92.5\" cy=\"12.5\" r=\"12.5\"><animate attributeName=\"fill-opacity\" begin=\"800ms\" dur=\"1s\" values=\"1;.2;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"92.5\" cy=\"52.5\" r=\"12.5\"><animate attributeName=\"fill-opacity\" begin=\"400ms\" dur=\"1s\" values=\"1;.2;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"12.5\" cy=\"92.5\" r=\"12.5\"><animate attributeName=\"fill-opacity\" begin=\"700ms\" dur=\"1s\" values=\"1;.2;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"52.5\" cy=\"92.5\" r=\"12.5\"><animate attributeName=\"fill-opacity\" begin=\"500ms\" dur=\"1s\" values=\"1;.2;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"92.5\" cy=\"92.5\" r=\"12.5\"><animate attributeName=\"fill-opacity\" begin=\"200ms\" dur=\"1s\" values=\"1;.2;1\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle></svg>\n";

  var hearts = "<svg class=\"quasar-spinner\" :fill=\"color\" :width=\"size\" :height=\"size\" viewBox=\"0 0 140 64\" xmlns=\"http://www.w3.org/2000/svg\"><path d=\"M30.262 57.02L7.195 40.723c-5.84-3.976-7.56-12.06-3.842-18.063 3.715-6 11.467-7.65 17.306-3.68l4.52 3.76 2.6-5.274c3.716-6.002 11.47-7.65 17.304-3.68 5.84 3.97 7.56 12.054 3.842 18.062L34.49 56.118c-.897 1.512-2.793 1.915-4.228.9z\" fill-opacity=\".5\"><animate attributeName=\"fill-opacity\" begin=\"0s\" dur=\"1.4s\" values=\"0.5;1;0.5\" calcMode=\"linear\" repeatCount=\"indefinite\"/></path><path d=\"M105.512 56.12l-14.44-24.272c-3.716-6.008-1.996-14.093 3.843-18.062 5.835-3.97 13.588-2.322 17.306 3.68l2.6 5.274 4.52-3.76c5.84-3.97 13.593-2.32 17.308 3.68 3.718 6.003 1.998 14.088-3.842 18.064L109.74 57.02c-1.434 1.014-3.33.61-4.228-.9z\" fill-opacity=\".5\"><animate attributeName=\"fill-opacity\" begin=\"0.7s\" dur=\"1.4s\" values=\"0.5;1;0.5\" calcMode=\"linear\" repeatCount=\"indefinite\"/></path><path d=\"M67.408 57.834l-23.01-24.98c-5.864-6.15-5.864-16.108 0-22.248 5.86-6.14 15.37-6.14 21.234 0L70 16.168l4.368-5.562c5.863-6.14 15.375-6.14 21.235 0 5.863 6.14 5.863 16.098 0 22.247l-23.007 24.98c-1.43 1.556-3.757 1.556-5.188 0z\"/></svg>\n";

  var hourglass = "<svg class=\"quasar-spinner\" :width=\"size\" :height=\"size\"  viewBox=\"0 0 100 100\" preserveAspectRatio=\"xMidYMid\" xmlns=\"http://www.w3.org/2000/svg\"><g><path fill=\"none\" :stroke=\"color\" stroke-width=\"5\" stroke-miterlimit=\"10\" d=\"M58.4,51.7c-0.9-0.9-1.4-2-1.4-2.3s0.5-0.4,1.4-1.4 C70.8,43.8,79.8,30.5,80,15.5H70H30H20c0.2,15,9.2,28.1,21.6,32.3c0.9,0.9,1.4,1.2,1.4,1.5s-0.5,1.6-1.4,2.5 C29.2,56.1,20.2,69.5,20,85.5h10h40h10C79.8,69.5,70.8,55.9,58.4,51.7z\" class=\"glass\"></path><clipPath id=\"uil-hourglass-clip1\"><rect x=\"15\" y=\"20\" width=\"70\" height=\"25\" class=\"clip\"><animate attributeName=\"height\" from=\"25\" to=\"0\" dur=\"1s\" repeatCount=\"indefinite\" vlaues=\"25;0;0\" keyTimes=\"0;0.5;1\"></animate><animate attributeName=\"y\" from=\"20\" to=\"45\" dur=\"1s\" repeatCount=\"indefinite\" vlaues=\"20;45;45\" keyTimes=\"0;0.5;1\"></animate></rect></clipPath><clipPath id=\"uil-hourglass-clip2\"><rect x=\"15\" y=\"55\" width=\"70\" height=\"25\" class=\"clip\"><animate attributeName=\"height\" from=\"0\" to=\"25\" dur=\"1s\" repeatCount=\"indefinite\" vlaues=\"0;25;25\" keyTimes=\"0;0.5;1\"></animate><animate attributeName=\"y\" from=\"80\" to=\"55\" dur=\"1s\" repeatCount=\"indefinite\" vlaues=\"80;55;55\" keyTimes=\"0;0.5;1\"></animate></rect></clipPath><path d=\"M29,23c3.1,11.4,11.3,19.5,21,19.5S67.9,34.4,71,23H29z\" clip-path=\"url(#uil-hourglass-clip1)\" :fill=\"color\" class=\"sand\"></path><path d=\"M71.6,78c-3-11.6-11.5-20-21.5-20s-18.5,8.4-21.5,20H71.6z\" clip-path=\"url(#uil-hourglass-clip2)\" :fill=\"color\" class=\"sand\"></path><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 50 50\" to=\"180 50 50\" repeatCount=\"indefinite\" dur=\"1s\" values=\"0 50 50;0 50 50;180 50 50\" keyTimes=\"0;0.7;1\"></animateTransform></g></svg>\n";

  var infinity = "<svg class=\"quasar-spinner\" :width=\"size\" :height=\"size\" viewBox=\"0 0 100 100\" preserveAspectRatio=\"xMidYMid\"><path d=\"M24.3,30C11.4,30,5,43.3,5,50s6.4,20,19.3,20c19.3,0,32.1-40,51.4-40C88.6,30,95,43.3,95,50s-6.4,20-19.3,20C56.4,70,43.6,30,24.3,30z\" fill=\"none\" :stroke=\"color\" stroke-width=\"8\" stroke-dasharray='10.691205342610678 10.691205342610678' stroke-dashoffset=\"0\"><animate attributeName=\"stroke-dashoffset\" from=\"0\" to=\"21.382410685221355\" begin=\"0\" dur=\"2s\" repeatCount=\"indefinite\" fill=\"freeze\"></animate></path></svg>\n";

  var ios = "<svg class=\"quasar-spinner\" :width=\"size\" :height=\"size\" viewBox=\"0 0 100 100\" preserveAspectRatio=\"xMidYMid\" xmlns=\"http://www.w3.org/2000/svg\"><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(0 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(30 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.08333333333333333s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(60 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.16666666666666666s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(90 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.25s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(120 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.3333333333333333s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(150 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.4166666666666667s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(180 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.5s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(210 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.5833333333333334s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(240 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.6666666666666666s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(270 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.75s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(300 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.8333333333333334s' repeatCount='indefinite'/></rect><rect x='46.5' y='40' width='7' height='20' rx='5' ry='5' :fill='color' transform='rotate(330 50 50) translate(0 -30)'><animate attributeName='opacity' from='1' to='0' dur='1s' begin='0.9166666666666666s' repeatCount='indefinite'/></rect></svg>\n";

  var oval = "<svg class=\"quasar-spinner\" :stroke=\"color\" :width=\"size\" :height=\"size\" viewBox=\"0 0 38 38\" xmlns=\"http://www.w3.org/2000/svg\"><g transform=\"translate(1 1)\" stroke-width=\"2\" fill=\"none\" fill-rule=\"evenodd\"><circle stroke-opacity=\".5\" cx=\"18\" cy=\"18\" r=\"18\"/><path d=\"M36 18c0-9.94-8.06-18-18-18\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 18 18\" to=\"360 18 18\" dur=\"1s\" repeatCount=\"indefinite\"/></path></g></svg>\n";

  var pie = "<svg class=\"quasar-spinner\" :width=\"size\" :height=\"size\" viewBox=\"0 0 100 100\" preserveAspectRatio=\"xMidYMid\" xmlns=\"http://www.w3.org/2000/svg\"><path d=\"M0 50A50 50 0 0 1 50 0L50 50L0 50\" :fill=\"color\" opacity=\"0.5\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 50 50\" to=\"360 50 50\" dur=\"0.8s\" repeatCount=\"indefinite\"></animateTransform></path><path d=\"M50 0A50 50 0 0 1 100 50L50 50L50 0\" :fill=\"color\" opacity=\"0.5\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 50 50\" to=\"360 50 50\" dur=\"1.6s\" repeatCount=\"indefinite\"></animateTransform></path><path d=\"M100 50A50 50 0 0 1 50 100L50 50L100 50\" :fill=\"color\" opacity=\"0.5\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 50 50\" to=\"360 50 50\" dur=\"2.4s\" repeatCount=\"indefinite\"></animateTransform></path><path d=\"M50 100A50 50 0 0 1 0 50L50 50L50 100\" :fill=\"color\" opacity=\"0.5\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 50 50\" to=\"360 50 50\" dur=\"3.2s\" repeatCount=\"indefinite\"></animateTransform></path></svg>\n";

  var puff = "<svg class=\"quasar-spinner\" :stroke=\"color\" :width=\"size\" :height=\"size\" viewBox=\"0 0 44 44\" xmlns=\"http://www.w3.org/2000/svg\"><g fill=\"none\" fill-rule=\"evenodd\" stroke-width=\"2\"><circle cx=\"22\" cy=\"22\" r=\"1\"><animate attributeName=\"r\" begin=\"0s\" dur=\"1.8s\" values=\"1; 20\" calcMode=\"spline\" keyTimes=\"0; 1\" keySplines=\"0.165, 0.84, 0.44, 1\" repeatCount=\"indefinite\"/><animate attributeName=\"stroke-opacity\" begin=\"0s\" dur=\"1.8s\" values=\"1; 0\" calcMode=\"spline\" keyTimes=\"0; 1\" keySplines=\"0.3, 0.61, 0.355, 1\" repeatCount=\"indefinite\"/></circle><circle cx=\"22\" cy=\"22\" r=\"1\"><animate attributeName=\"r\" begin=\"-0.9s\" dur=\"1.8s\" values=\"1; 20\" calcMode=\"spline\" keyTimes=\"0; 1\" keySplines=\"0.165, 0.84, 0.44, 1\" repeatCount=\"indefinite\"/><animate attributeName=\"stroke-opacity\" begin=\"-0.9s\" dur=\"1.8s\" values=\"1; 0\" calcMode=\"spline\" keyTimes=\"0; 1\" keySplines=\"0.3, 0.61, 0.355, 1\" repeatCount=\"indefinite\"/></circle></g></svg>\n";

  var radio = "<svg class=\"quasar-spinner\" :width=\"size\" :height=\"size\" viewBox=\"0 0 100 100\" preserveAspectRatio=\"xMidYMid\" xmlns=\"http://www.w3.org/2000/svg\"><g transform=\"scale(0.55)\"><circle cx=\"30\" cy=\"150\" r=\"30\" :fill=\"color\"><animate attributeName=\"opacity\" from=\"0\" to=\"1\" dur=\"1s\" begin=\"0\" repeatCount=\"indefinite\" keyTimes=\"0;0.5;1\" values=\"0;1;1\"></animate></circle><path d=\"M90,150h30c0-49.7-40.3-90-90-90v30C63.1,90,90,116.9,90,150z\" :fill=\"color\"><animate attributeName=\"opacity\" from=\"0\" to=\"1\" dur=\"1s\" begin=\"0.1\" repeatCount=\"indefinite\" keyTimes=\"0;0.5;1\" values=\"0;1;1\"></animate></path><path d=\"M150,150h30C180,67.2,112.8,0,30,0v30C96.3,30,150,83.7,150,150z\" :fill=\"color\"><animate attributeName=\"opacity\" from=\"0\" to=\"1\" dur=\"1s\" begin=\"0.2\" repeatCount=\"indefinite\" keyTimes=\"0;0.5;1\" values=\"0;1;1\"></animate></path></g></svg>\n";

  var rings = "<svg class=\"quasar-spinner\" :stroke=\"color\" :width=\"size\" :height=\"size\" viewBox=\"0 0 45 45\" xmlns=\"http://www.w3.org/2000/svg\"><g fill=\"none\" fill-rule=\"evenodd\" transform=\"translate(1 1)\" stroke-width=\"2\"><circle cx=\"22\" cy=\"22\" r=\"6\"><animate attributeName=\"r\" begin=\"1.5s\" dur=\"3s\" values=\"6;22\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"stroke-opacity\" begin=\"1.5s\" dur=\"3s\" values=\"1;0\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"stroke-width\" begin=\"1.5s\" dur=\"3s\" values=\"2;0\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"22\" cy=\"22\" r=\"6\"><animate attributeName=\"r\" begin=\"3s\" dur=\"3s\" values=\"6;22\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"stroke-opacity\" begin=\"3s\" dur=\"3s\" values=\"1;0\" calcMode=\"linear\" repeatCount=\"indefinite\"/><animate attributeName=\"stroke-width\" begin=\"3s\" dur=\"3s\" values=\"2;0\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle><circle cx=\"22\" cy=\"22\" r=\"8\"><animate attributeName=\"r\" begin=\"0s\" dur=\"1.5s\" values=\"6;1;2;3;4;5;6\" calcMode=\"linear\" repeatCount=\"indefinite\"/></circle></g></svg>\n";

  var tail = "<svg class=\"quasar-spinner\" :width=\"size\" :height=\"size\" viewBox=\"0 0 38 38\" xmlns=\"http://www.w3.org/2000/svg\"><defs><linearGradient x1=\"8.042%\" y1=\"0%\" x2=\"65.682%\" y2=\"23.865%\" id=\"a\"><stop :stop-color=\"color\" stop-opacity=\"0\" offset=\"0%\"/><stop :stop-color=\"color\" stop-opacity=\".631\" offset=\"63.146%\"/><stop :stop-color=\"color\" offset=\"100%\"/></linearGradient></defs><g transform=\"translate(1 1)\" fill=\"none\" fill-rule=\"evenodd\"><path d=\"M36 18c0-9.94-8.06-18-18-18\" stroke=\"url(#a)\" stroke-width=\"2\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 18 18\" to=\"360 18 18\" dur=\"0.9s\" repeatCount=\"indefinite\"/></path><circle :fill=\"color\" cx=\"36\" cy=\"18\" r=\"1\"><animateTransform attributeName=\"transform\" type=\"rotate\" from=\"0 18 18\" to=\"360 18 18\" dur=\"0.9s\" repeatCount=\"indefinite\"/></circle></g></svg>\n";

  var templates = {
    audio: audio, ball: ball, bars: bars, circles: circles, dots: dots, facebook: facebook, gears: gears, grid: grid, hearts: hearts,
    hourglass: hourglass, infinity: infinity, ios: ios, oval: oval, pie: pie, puff: puff, radio: radio, rings: rings, tail: tail
  };

  var registerSpinners = (function (_Vue) {
    Object.keys(templates).forEach(function (spinner) {
      _Vue.partial('quasar-partial-' + spinner, templates[spinner]);
    });

    _Vue.component('spinner', {
      template: '<span><partial :name="partialName"></partial></span>',
      props: {
        name: {
          type: String,
          default: theme === 'ios' ? 'ios' : 'tail'
        },
        size: {
          type: Number,
          default: 64
        },
        color: {
          type: String,
          default: '#000'
        }
      },
      computed: {
        partialName: function partialName() {
          return 'quasar-partial-' + this.name;
        }
      }
    });
  });

  var State = { template: "<span><slot v-if=!model></slot><slot v-else=\"\" name=active></slot></span>",
    props: {
      model: {
        type: Boolean,
        required: true,
        twoWay: true
      }
    }
  };

  var Tab = { template: "<div class=\"quasar-tab items-center justify-center\" :class=\"{'v-link-active': active, hidden: hidden, disabled: disabled, hideIcon: hide === 'icon', hideLabel: hide === 'label'}\" @click=activate()><i v-if=icon class=quasar-tabs-icon>{{icon}}</i> <span class=quasar-tab-label><slot></slot></span></div>",
    props: ['active', 'hidden', 'disabled', 'hide', 'icon', 'label', 'target'],
    methods: {
      activate: function activate() {
        if (this.disabled) {
          return;
        }
        this.active = true;
      }
    },
    events: {
      blur: function blur(tab) {
        if (tab === this) {
          return;
        }
        this.active = false;
      }
    },
    watch: {
      active: function active(value) {
        if (this.disabled) {
          return;
        }
        if (value) {
          this.$dispatch('selected', this, this.$el);
        }
      },
      hidden: function hidden(value) {
        this.$dispatch('hidden');
      },
      '$route': function $route(value) {
        var _this = this;

        this.$nextTick(function () {
          if (_this.$el.classList.contains('v-link-active')) {
            _this.$dispatch('selected', _this, _this.$el);
          }
        });
      }
    },
    ready: function ready() {
      var _this2 = this;

      if (this.active && this.target || this.$el.classList.contains('v-link-active')) {
        this.$nextTick(function () {
          _this2.$dispatch('selected', _this2, _this2.$el);
        });
      }
    }
  };

  var scrollNavigationSpeed = 5;
  var debounceDelay = 50;
  var Tabs = { template: "<div class=\"quasar-tabs row\"><div class=\"row items-center justify-center left-scroll\"><i>chevron_left</i></div><div class=\"quasar-tabs-scroller row\"><slot></slot></div><div class=\"row items-center justify-center right-scroll\"><i>chevron_right</i></div></div>",
    methods: {
      redraw: function redraw() {
        if (!Platform.is.desktop) {
          return;
        }
        if (Utils.dom.width(this.scroller) === 0 && this.scroller.scrollWidth === 0) {
          return;
        }
        if (Utils.dom.width(this.scroller) + 5 < this.scroller.scrollWidth) {
          this.$el.classList.add('scrollable');
          this.scrollable = true;
          this.updateScrollIndicator();
        } else {
          this.$el.classList.remove('scrollable');
          this.scrollable = false;
        }
      },
      updateScrollIndicator: function updateScrollIndicator() {
        if (!Platform.is.desktop || !this.scrollable) {
          return;
        }

        var action = this.scroller.scrollLeft + Utils.dom.width(this.scroller) + 5 >= this.scroller.scrollWidth ? 'add' : 'remove';

        this.leftScroll.classList[this.scroller.scrollLeft <= 0 ? 'add' : 'remove']('disabled');
        this.rightScroll.classList[action]('disabled');
      },
      scrollToSelectedIfNeeded: function scrollToSelectedIfNeeded(tab) {
        if (tab.length === 0 || !this.scrollable) {
          return;
        }

        var contentRect = this.scroller.getBoundingClientRect(),
            tabRect = tab.getBoundingClientRect(),
            tabWidth = tabRect.width,
            offset = tabRect.left - contentRect.left;

        if (offset < 0) {
          this.animScrollTo(this.scroller.scrollLeft + offset);
        } else {
          offset += tabWidth - this.scroller.offsetWidth;

          if (offset > 0) {
            this.animScrollTo(this.scroller.scrollLeft + offset);
          }
        }
      },
      animScrollTo: function animScrollTo(value) {
        var _this = this;

        if (this.scrollTimer) {
          clearInterval(this.scrollTimer);
        }

        this.scrollTowards(value);
        this.scrollTimer = setInterval(function () {
          if (_this.scrollTowards(value)) {
            clearInterval(_this.scrollTimer);
          }
        }, 5);
      },
      scrollTowards: function scrollTowards(value) {
        var scrollPosition = this.scroller.scrollLeft,
            direction = value < scrollPosition ? -1 : 1,
            done = false;

        scrollPosition += direction * scrollNavigationSpeed;

        if (scrollPosition < 0) {
          done = true;
          scrollPosition = 0;
        } else if (direction === -1 && scrollPosition <= value || direction === 1 && scrollPosition >= value) {
          done = true;
          scrollPosition = value;
        }

        this.scroller.scrollLeft = scrollPosition;
        return done;
      }
    },
    events: {
      selected: function selected(tab, tabNode) {
        var _this2 = this;

        if (this.content.length > 0) {
          [].forEach.call(this.content, function (el) {
            el.style.display = 'none';
          });
          document.querySelector(tab.target).style.display = '';
        }

        this.$broadcast('blur', tab);

        setTimeout(function () {
          _this2.scrollToSelectedIfNeeded(tabNode);
        }, debounceDelay * 4);
      },
      hidden: function hidden() {
        this.redraw();
      }
    },
    ready: function ready() {
      var _this3 = this;

      this.scrollTimer = null;
      this.scrollable = !Platform.is.desktop;

      this.scroller = this.$el.getElementsByClassName('quasar-tabs-scroller')[0];
      this.leftScroll = this.$el.getElementsByClassName('left-scroll')[0];
      this.rightScroll = this.$el.getElementsByClassName('right-scroll')[0];

      this.redraw = Utils.debounce(this.redraw, debounceDelay);
      this.updateScrollIndicator = Utils.debounce(this.updateScrollIndicator, debounceDelay);

      this.content = this.$children.filter(function (child) {
        return child.target;
      });
      if (this.content.length > 0) {
        this.content = document.querySelectorAll(this.content.map(function (child) {
          return child.target;
        }).join(','));[].forEach.call(this.content, function (el) {
          el.style.display = 'none';
        });
      }

      this.scroller.addEventListener('scroll', this.updateScrollIndicator);
      window.addEventListener('resize', this.redraw);

      setTimeout(function () {
        _this3.redraw();
      }, debounceDelay);

      if (Platform.is.desktop) {
        var scrollEvents = {
          start: [],
          stop: []
        };

        scrollEvents.start.push('mousedown');
        scrollEvents.stop.push('mouseup');

        if (Platform.has.touch) {
          scrollEvents.start.push('touchstart');
          scrollEvents.stop.push('touchend');
        }

        scrollEvents.start.forEach(function (evt) {
          _this3.leftScroll.addEventListener(evt, function () {
            _this3.animScrollTo(0);
          });
          _this3.rightScroll.addEventListener(evt, function () {
            _this3.animScrollTo(9999);
          });
        });
        scrollEvents.stop.forEach(function (evt) {
          _this3.leftScroll.addEventListener(evt, function () {
            clearInterval(_this3.scrollTimer);
          });
          _this3.rightScroll.addEventListener(evt, function () {
            clearInterval(_this3.scrollTimer);
          });
        });
      }
    },
    beforeDestroy: function beforeDestroy() {
      if (this.scrollTimer) {
        clearInterval(this.scrollTimer);
      }
      this.scroller.removeEventListener('scroll', this.updateScrollIndicator);
      window.removeEventListener('resize', this.redraw);
    }
  };

  var Toggle = { template: "<label class=quasar-toggle v-touch:pan=toggle v-touch-options:pan=\"{ direction: 'horizontal' }\"><input type=checkbox v-model=model><div></div></label>",
    props: {
      model: {
        type: Boolean,
        twoWay: true,
        required: true
      }
    },
    methods: {
      toggle: function toggle(event) {
        if (event.isFinal && (this.model && event.deltaX < 0 || !this.model && event.deltaX > 0)) {
          this.model = !this.model;
        }
      }
    }
  };

  var Tree = { template: "<div class=quasar-tree><ul><quasar-tree-item v-for=\"item in model\" :model=item :contract-html=contractHtml :expand-html=expandHtml></quasar-tree-item></ul></div>",
    props: {
      model: {
        type: Array,
        required: true
      },
      contractHtml: {
        type: String,
        required: true
      },
      expandHtml: {
        type: String,
        required: true
      }
    }
  };

  var TreeItem = { template: "<li class=quasar-tree-item><div :class=\"{'quasar-tree-expandable-item': isExpandable, 'quasar-tree-link': model.handler}\" @click=toggle><i v-if=model.icon>{{model.icon}}</i> <span class=quasar-tree-label>{{model.title}}</span> <span v-if=isExpandable>{{{model.expanded ? contractHtml : expandHtml}}}</span></div><ul v-show=model.expanded v-if=isExpandable transition=slide><quasar-tree-item v-for=\"item in model.children\" :model=item :contract-html=contractHtml :expand-html=expandHtml></quasar-tree-item></ul>",
    props: ['model', 'contract-html', 'expand-html'],
    methods: {
      toggle: function toggle() {
        if (this.isExpandable) {
          this.model.expanded = !this.model.expanded;
          return;
        }

        if (typeof this.model.handler === 'function') {
          this.model.handler(this.model);
        }
      }
    },
    computed: {
      isExpandable: function isExpandable() {
        return this.model.children && this.model.children.length;
      }
    }
  };

  var Video = { template: "<div class=video><iframe :src=source frameborder=0 allowfullscreen></iframe></div>",
    props: ['src']
  };

  function registerTransitions(_Vue) {
    _Vue.transition('slide', transitionSlide);
  }

  function registerFilters(_Vue) {
    _Vue.filter('gridShowSelected', GridSelectedFilter);
  }

  function registerDirectives(_Vue) {
    _Vue.directive('attr', directiveAttr);
    _Vue.directive('collapsible', directiveCollapsible);
    _Vue.directive('scroll-fire', directiveScrollFire);
    _Vue.directive('scroll', directiveScroll);
    _Vue.directive('tooltip', directiveTooltip);
  }

  function registerComponents(_Vue) {
    _Vue.component('quasar-checkbox', Checkbox);
    _Vue.component('quasar-context-menu', ContextMenu);
    _Vue.component('quasar-drawer', Drawer);
    _Vue.component('quasar-drawer-link', DrawerLink);
    _Vue.component('quasar-dropdown', Dropdown);
    _Vue.component('quasar-fab', Fab);
    _Vue.component('quasar-small-fab', SmallFab);
    _Vue.component('quasar-gallery', Gallery);
    _Vue.component('quasar-gallery-slider', GallerySlider);
    _Vue.component('quasar-grid', Grid);
    _Vue.component('quasar-grid-table', GridTable);
    _Vue.component('quasar-infinite-scroll', InfiniteScroll);
    _Vue.component('quasar-layout', Layout);
    _Vue.component('quasar-toolbar-title', ToolbarTitle);
    _Vue.component('quasar-numeric', Numeric);
    _Vue.component('quasar-pagination', Pagination);
    _Vue.component('quasar-parallax', Parallax);
    _Vue.component('quasar-progress', Progress);
    _Vue.component('quasar-pull-to-refresh', PullToRefresh);
    _Vue.component('quasar-radio', Radio);
    _Vue.component('quasar-range', Range);
    _Vue.component('quasar-rating', Rating);
    _Vue.component('quasar-search', Search);
    _Vue.component('quasar-select', Select);
    _Vue.component('quasar-slider', Slider);
    _Vue.component('quasar-state', State);
    _Vue.component('quasar-tab', Tab);
    _Vue.component('quasar-tabs', Tabs);
    _Vue.component('quasar-toggle', Toggle);
    _Vue.component('quasar-tree', Tree);
    _Vue.component('quasar-tree-item', TreeItem);
    _Vue.component('quasar-video', Video);
  }

  var Vue;

  function install (_Vue) {
    if (this.installed) {
      console.warn('Quasar already installed in Vue.');
      return;
    }

    Vue = _Vue;

    registerTransitions(_Vue);
    registerFilters(_Vue);
    registerDirectives(_Vue);
    registerComponents(_Vue);
    registerSpinners(_Vue);
  }

  function addClass(className) {
    document.body.classList.add(className);
  }

  addClass(Platform.is.desktop ? 'desktop' : 'mobile');
  addClass(Platform.has.touch ? 'touch' : 'no-touch');

  if (Platform.within.iframe) {
    addClass('within-iframe');
  }

  if (Platform.is.cordova) {
    addClass('cordova');
  }

  function start () {
    var callback = arguments.length <= 0 || arguments[0] === undefined ? function () {} : arguments[0];

    if (!theme) {
      set(Platform.is.ios ? 'ios' : 'mat');
    }

    if (Platform.is.cordova && !Platform.within.iframe) {
      var tag = document.createElement('script');

      document.addEventListener('deviceready', callback, false);

      tag.type = 'text/javascript';
      document.body.appendChild(tag);
      tag.src = 'cordova.js';

      return;
    }

    callback();
  }

  function init (Quasar) {
    if (typeof window !== 'undefined' && window.Vue) {
      window.Quasar = Quasar;
      window.Vue.use(Quasar);
    }
  }

  if (!Array.prototype.includes) {
    Array.prototype.includes = function (searchElement, startFrom) {
      'use strict';

      var O = Object(this);
      var len = parseInt(O.length, 10) || 0;
      if (len === 0) {
        return false;
      }
      var n = parseInt(startFrom, 10) || 0;
      var k = void 0;
      if (n >= 0) {
        k = n;
      } else {
        k = len + n;
        if (k < 0) {
          k = 0;
        }
      }
      var currentElement = void 0;
      while (k < len) {
        currentElement = O[k];
        if (searchElement === currentElement || searchElement !== searchElement && currentElement !== currentElement) {
          return true;
        }
        k++;
      }
      return false;
    };
  }

  if (!String.prototype.startsWith) {
    String.prototype.startsWith = function (searchString, position) {
      position = position || 0;
      return this.substr(position, searchString.length) === searchString;
    };
  }

  if (!String.prototype.endsWith) {
    String.prototype.endsWith = function (searchString, position) {
      var subjectString = this.toString();

      if (typeof position !== 'number' || !isFinite(position) || Math.floor(position) !== position || position > subjectString.length) {
        position = subjectString.length;
      }
      position -= searchString.length;

      var lastIndex = subjectString.indexOf(searchString, position);

      return lastIndex !== -1 && lastIndex === position;
    };
  }

  if (typeof Element.prototype.matches !== 'function') {
    Element.prototype.matches = Element.prototype.msMatchesSelector || Element.prototype.mozMatchesSelector || Element.prototype.webkitMatchesSelector || function matches(selector) {
      var element = this,
          elements = (element.document || element.ownerDocument).querySelectorAll(selector),
          index = 0;

      while (elements[index] && elements[index] !== element) {
        ++index;
      }

      return Boolean(elements[index]);
    };
  }

  if (typeof Element.prototype.closest !== 'function') {
    Element.prototype.closest = function closest(selector) {
      var element = this;

      while (element && element.nodeType === 1) {
        if (element.matches(selector)) {
          return element;
        }

        element = element.parentNode;
      }

      return null;
    };
  }

  function parseEventNames(eventNames) {
    return eventNames.trim().replace(/\s\s+/g, ' ').split(' ');
  }

  function remove(events, eventName, filterFn) {
    events[eventName] = events[eventName].filter(filterFn);
    if (events[eventName].length === 0) {
      delete events[eventName];
    }
  }

  function on(eventNames, callback, context, once) {
    var _this = this;

    if (!eventNames) {
      throw new Error('Missing event(s) name(s)');
    }
    if (!callback) {
      throw new Error('Missing callback');
    }
    if (typeof callback !== 'function') {
      throw new Error('Callback is not a function');
    }

    parseEventNames(eventNames).forEach(function (eventName) {
      if (!_this.events.hasOwnProperty(eventName)) {
        _this.events[eventName] = [];
      }

      if (_this.events[eventName].some(function (item) {
        return item.cb === callback;
      })) {
        return;
      }

      _this.events[eventName].push({
        cb: callback,
        context: context,
        once: once
      });
    });
  }

  function off(eventNames, callback) {
    var _this2 = this;

    if (!eventNames) {
      this.events = {};
      return;
    }

    if (callback && typeof callback !== 'function') {
      throw new Error('Callback is not a function');
    }

    parseEventNames(eventNames).forEach(function (eventName) {
      if (!_this2.events.hasOwnProperty(eventName)) {
        return;
      }

      if (!callback) {
        delete _this2.events[eventName];
        return;
      }

      remove(_this2.events, eventName, function (ev) {
        return ev.cb !== callback;
      });
    });
  }

  function once(eventNames, callback, context) {
    on.call(this, eventNames, callback, context, true);
  }

  function trigger(eventNames) {
    var _this3 = this;

    for (var _len = arguments.length, args = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
      args[_key - 1] = arguments[_key];
    }

    if (!eventNames) {
      eventNames = getList.call(this).join(' ');
    }

    parseEventNames(eventNames).forEach(function (eventName) {
      if (!_this3.events.hasOwnProperty(eventName)) {
        return;
      }

      var onceList = [];

      _this3.events[eventName].forEach(function (ev) {
        ev.cb.apply(ev.context, args);
        if (ev.once) {
          onceList.push(ev);
        }
      });

      remove(_this3.events, eventName, function (ev) {
        return !onceList.includes(ev);
      });
    });
  }

  function hasSubscriber(eventNames, callback) {
    var _this4 = this;

    if (!eventNames) {
      return Object.keys(this.events).length !== 0;
    }

    if (typeof eventNames === 'function') {
      callback = eventNames;
      eventNames = getList.call(this).join(' ');
    }

    if (callback && typeof callback !== 'function') {
      throw new Error('Callback is not a function');
    }

    var foundSubscriber = false;

    parseEventNames(eventNames).forEach(function (eventName) {
      var result = _this4.events.hasOwnProperty(eventName);

      if (!result) {
        return;
      }

      if (callback) {
        result = _this4.events[eventName].some(function (item) {
          return item.cb === callback;
        });

        if (result) {
          foundSubscriber = true;
        }
        return;
      }

      foundSubscriber = true;
    });

    return foundSubscriber;
  }

  function getList() {
    return Object.keys(this.events);
  }

  function createEmitter() {
    var props = {
      events: {}
    };

    return {
      on: on.bind(props),
      off: off.bind(props),
      once: once.bind(props),
      trigger: trigger.bind(props),

      hasSubscriber: hasSubscriber.bind(props),
      getList: getList.bind(props)
    };
  }

  var Events = createEmitter();

  window.onerror = function (message, source, lineno, colno, error) {
    Events.trigger('app:error', {
      message: message,
      source: source,
      lineno: lineno,
      colno: colno,
      error: error
    });
  };

  if (Platform.has.touch) {
    FastClick.attach(document.body);
  }

  var matTemplate = "<div v-if=\"title\" class=\"modal-header\">\n  {{{* title}}}\n</div>\n\n<div class=\"modal-scroll\">\n  <div v-if=\"gallery\" class=\"quasar-action-sheet-gallery row wrap items-center justify-center\">\n    <div\n      v-for=\"button in buttons\"\n      class=\"cursor-pointer column inline items-center justify-center\"\n      @click=\"close(button.handler)\"\n      :class=\"button.classes\"\n    >\n      <i v-if=\"button.icon\">{{* button.icon}}</i>\n      <img v-if=\"button.avatar\" :src=\"button.avatar\" class=\"avatar\">\n\n      <span>{{* button.label}}</span>\n    </div>\n  </div>\n  <div v-else class=\"list inset\">\n    <div\n      v-for=\"button in buttons\"\n      class=\"item item-link\"\n      @click=\"close(button.handler)\"\n      :class=\"button.classes\"\n    >\n      <i v-if=\"button.icon\">{{* button.icon}}</i>\n      <img v-if=\"button.avatar\" :src=\"button.avatar\" class=\"avatar\">\n      <div class=\"item-content\">\n        {{* button.label}}\n      </div>\n    </div>\n  </div>\n</div>\n\n<div class=\"list inset\">\n  <div\n    class=\"item item-link\"\n    @click=\"close(dismissButton.handler)\"\n    :class=\"dismissButton.classes\"\n  >\n    <i v-if=\"dismissButton.icon\">{{* dismissButton.icon}}</i>\n    <div class=\"item-content\">\n      {{* dismissButton.label}}\n    </div>\n  </div>\n</div>\n";

  var iosTemplate = "<div class=\"quasar-action-sheet\">\n  <div v-if=\"title\" class=\"item justify-center faded\">\n    <span class=\"item-value\">{{{* title}}}</span>\n  </div>\n\n  <div class=\"modal-controls modal-scroll\">\n    <div v-if=\"gallery\" class=\"quasar-action-sheet-gallery row wrap items-center justify-center\">\n      <div\n        v-for=\"button in buttons\"\n        class=\"cursor-pointer column inline items-center justify-center\"\n        @click=\"close(button.handler)\"\n        :class=\"button.classes\"\n      >\n        <i v-if=\"button.icon\">{{* button.icon}}</i>\n        <img v-if=\"button.avatar\" :src=\"button.avatar\" class=\"avatar\">\n\n        <span>{{* button.label}}</span>\n      </div>\n    </div>\n    <div v-else class=\"list item-delimiter\">\n      <div\n        v-for=\"button in buttons\"\n        class=\"item item-link justify-center\"\n        @click=\"close(button.handler)\"\n        :class=\"button.classes\"\n      >\n        <i v-if=\"button.icon\">{{* button.icon}}</i>\n        <img v-if=\"button.avatar\" :src=\"button.avatar\" class=\"avatar\">\n        <span style=\"margin-left: 15px;\">{{* button.label}}</span>\n      </div>\n    </div>\n  </div>\n</div>\n\n<div class=\"quasar-action-sheet\">\n  <div\n    class=\"item item-link justify-center\"\n    @click=\"close(dismissButton.handler)\"\n    :class=\"dismissButton.classes\"\n  >\n    <strong>{{* dismissButton.label}}</strong>\n  </div>\n</div>\n";

  function parseButtons$1(buttons) {
    if (!Array.isArray(buttons)) {
      throw new Error('Action Sheet buttons parameter must be an array.');
    }

    if (buttons.length <= 1) {
      throw new Error('Action Sheet requires at least one button');
    }

    if (buttons.some(function (button) {
      return Object(button) !== button || !button.label || !button.handler;
    })) {
      throw new Error('At least one of Action Sheet\'s button parameter is not an object or missing label and/or handler.');
    }

    return buttons.map(function (button) {
      if (button.classes) {
        if (Array.isArray(button.classes)) {
          button.classes = button.classes.split(' ');
        } else if (typeof button.classes !== 'string') {
          throw new Error('Action Sheet button "classes" parameter must be either an array or string');
        }
      }
      return button;
    });
  }

  function getCSS() {
    if (theme === 'ios') {
      return {
        maxHeight: '80vh',
        height: 'auto',
        backgroundColor: 'transparent',
        boxShadow: 'none'
      };
    }

    return {
      maxHeight: '80vh',
      height: 'auto'
    };
  }

  function create$1(data) {
    data.buttons = parseButtons$1(data.buttons);
    data.dismissButton = data.buttons.pop();

    var modal = Modal$1.create({
      template: theme === 'ios' ? iosTemplate : matTemplate,
      data: data
    }).css(getCSS()).set({
      transitionIn: { translateY: [0, '101%'] },
      transitionOut: { translateY: ['101%', 0] }
    });

    modal.$el.classList.remove('items-center');
    modal.$el.classList.add('items-end');
    modal.$backdrop.addEventListener('click', function () {
      modal.close(data.dismissButton.handler);
    });

    return modal;
  }

  var ActionSheet = {
    create: create$1
  };

  document.body.innerHTML += '<div id="__quasar_toasts" class="column"></div>';

  var toastNode = document.getElementById('__quasar_toasts');
  var dismissers = [];
  var types = [{
    name: 'positive',
    defaults: { icon: 'check', color: 'positive' }
  }, {
    name: 'negative',
    defaults: { icon: 'whatshot', color: 'negative' }
  }, {
    name: 'info',
    defaults: { icon: 'info', color: 'info' }
  }, {
    name: 'warning',
    defaults: { icon: 'warning', color: 'warning' }
  }];
  function dismissAll() {
    dismissers.forEach(function (dismiss) {
      dismiss();
    });
  }

  var Toast = function () {
    function Toast(options) {
      var _this = this;

      classCallCheck(this, Toast);

      var dismiss = function dismiss() {
        _this.dismiss(true);
      },
          color = options.color ? 'custom-background bg-' + options.color : '';

      this.timeout = typeof options.timeout !== 'undefined' ? options.timeout : 7000;
      this.onDismiss = options.onDismiss || function () {};

      this.vm = new Vue({
        template: '<div\n        class="quasar-toast row items-center justify-between nowrap non-selectable ' + color + '"\n        v-touch:pan="pan"\n        v-touch-options:pan="{ direction: \'horizontal\' }">' + (options.icon ? '<i>' + options.icon + '</i>' : '') + (options.image ? '<img src="' + options.image + '">' : '') + ('<div class="auto">' + options.html + '</div>') + (options.button ? '<a @click="toastButton">' + options.button.label + '</a>' : '') + '<a @click="dismissAll" class="quasar-toast-dismiss-all"><i>delete</i></a></div>',
        methods: {
          pan: function pan(event) {
            var delta = event.deltaX,
                opacity = 0.9 - Math.abs(delta) / 180;

            Velocity(this.$el, 'stop');

            if (opacity < 0.05) {
              this.$el.style.opacity = '0';
              dismiss();
              return;
            }

            if (event.isFinal) {
              Velocity(this.$el, {
                translateX: [0, delta],
                opacity: 0.9
              });
              return;
            }

            Utils.dom.css(this.$el, {
              transform: 'translateX(' + delta + 'px)',
              opacity: opacity
            });
          },

          dismissAll: dismissAll,
          toastButton: function toastButton() {
            _this.dismiss();
            if (options.button && typeof options.button.handler === 'function') {
              options.button.handler();
            }
          }
        }
      });
      this.vm.$mount().$appendTo(toastNode);

      if (this.timeout > 0) {
        this.timer = setTimeout(function () {
          _this.dismiss();
        }, this.timeout);
      }

      Events.trigger('app:toast', this.html);
      Velocity(this.vm.$el, 'slideDown', {
        easing: 'easeOutQuart',
        display: 'flex'
      });

      if (dismissers.length > 5) {
        dismissers.shift()();
      }
      dismissers.push(function () {
        _this.dismiss();
      });

      return {
        node: this.node,
        dismiss: this.dismiss.bind(this)
      };
    }

    createClass(Toast, [{
      key: 'dismiss',
      value: function dismiss(swipedOut) {
        var _this2 = this;

        if (this.dismissed) {
          return;
        }

        this.dismissed = true;

        if (this.timer) {
          clearTimeout(this.timer);
        }

        if (swipedOut) {
          this.vm.$destroy(true);
          this.onDismiss();
        } else {
          Velocity(this.vm.$el, 'slideUp', {
            complete: function complete() {
              _this2.vm.$destroy(true);
              _this2.onDismiss();
            }
          });
        }

        dismissers = dismissers.filter(function (item) {
          return item !== _this2.dismiss;
        });
      }
    }]);
    return Toast;
  }();

  function create$2(opts, defaults) {
    if (!opts) {
      throw new Error('Missing toast options.');
    }

    var options = Utils.extend(true, typeof opts === 'string' ? { html: opts } : opts, defaults);

    if (!options.html) {
      throw new Error('Missing toast content/HTML.');
    }

    return new Toast(options);
  }

  types.forEach(function (type) {
    create$2[type.name] = function (opts) {
      return create$2(opts, type.defaults);
    };
  });

  var Toast$1 = {
    create: create$2
  };

  function isActive() {
    return document.fullscreenElement || document.mozFullScreenElement || document.webkitFullscreenElement || document.msFullscreenElement;
  }

  function request(target) {
    target = target || document.documentElement;

    if (isActive()) {
      return;
    }

    if (target.requestFullscreen) {
      target.requestFullscreen();
    } else if (target.msRequestFullscreen) {
      target.msRequestFullscreen();
    } else if (target.mozRequestFullScreen) {
      target.mozRequestFullScreen();
    } else if (target.webkitRequestFullscreen) {
      target.webkitRequestFullscreen(Element.ALLOW_KEYBOARD_INPUT);
    }
  }

  function exit() {
    if (document.exitFullscreen) {
      document.exitFullscreen();
    } else if (document.msExitFullscreen) {
      document.msExitFullscreen();
    } else if (document.mozCancelFullScreen) {
      document.mozCancelFullScreen();
    } else if (document.webkitExitFullscreen) {
      document.webkitExitFullscreen();
    }
  }

  function toggle(target) {
    if (isActive()) {
      exit();
    } else {
      request(target);
    }
  }

  var AppFullscreen = {
    isActive: isActive,
    request: request,
    exit: exit,
    toggle: toggle
  };

  var hidden = 'hidden';
  var appVisibility = 'visible';
  function onchange(evt) {
    var v = 'visible',
        h = 'hidden',
        state = void 0,
        evtMap = {
      focus: v,
      focusin: v,
      pageshow: v,
      blur: h,
      focusout: h,
      pagehide: h
    };

    evt = evt || window.event;

    if (evt.type in evtMap) {
      state = evtMap[evt.type];
    } else {
      state = this[hidden] ? h : v;
    }

    appVisibility = state;
    Events.trigger('app:visibility', state);
  }

  Utils.dom.ready(function () {
    if (hidden in document) {
      document.addEventListener('visibilitychange', onchange);
    } else if ((hidden = 'mozHidden') in document) {
      document.addEventListener('mozvisibilitychange', onchange);
    } else if ((hidden = 'webkitHidden') in document) {
      document.addEventListener('webkitvisibilitychange', onchange);
    } else if ((hidden = 'msHidden') in document) {
      document.addEventListener('msvisibilitychange', onchange);
    } else if ('onfocusin' in document) {
        document.onfocusin = document.onfocusout = onchange;
      } else {
          window.onpageshow = window.onpagehide = window.onfocus = window.onblur = onchange;
        }

    if (document[hidden] !== undefined) {
      onchange({ type: document[hidden] ? 'blur' : 'focus' });
    }
  });

  var AppVisibility = {
    isVisible: function isVisible() {
      return appVisibility === 'visible';
    }
  };

  function encode(string) {
    return encodeURIComponent(string);
  }

  function decode(string) {
    return decodeURIComponent(string);
  }

  function stringifyCookieValue(value) {
    return encode(value === Object(value) ? JSON.stringify(value) : '' + value);
  }

  function read(string) {
    if (string === '') {
      return string;
    }

    if (string.indexOf('"') === 0) {
      string = string.slice(1, -1).replace(/\\"/g, '"').replace(/\\\\/g, '\\');
    }

    string = decode(string.replace(/\+/g, ' '));

    try {
      string = JSON.parse(string);
    } catch (e) {}

    return string;
  }

  function set$2(key, value) {
    var options = arguments.length <= 2 || arguments[2] === undefined ? {} : arguments[2];

    var days = options.expires,
        time = options.expires = new Date();

    if (typeof options.expires === 'number') {
      time.setMilliseconds(time.getMilliseconds() + days * 864e+5);
    }

    document.cookie = [encode(key), '=', stringifyCookieValue(value), options.expires ? ' expires=' + options.expires.toUTCString() : '', options.path ? ' path=' + options.path : '', options.domain ? ' domain=' + options.domain : '', options.secure ? ' secure' : ''].join('');
  }

  function get$1(key) {
    var result = key ? undefined : {},
        cookies = document.cookie ? document.cookie.split(' ') : [],
        i = 0,
        l = cookies.length,
        parts = void 0,
        name = void 0,
        cookie = void 0;

    for (; i < l; i++) {
      parts = cookies[i].split('=');
      name = decode(parts.shift());
      cookie = parts.join('=');

      if (key === name) {
        result = read(cookie);
        break;
      }

      result[name] = cookie;
    }

    return result;
  }

  function remove$1(key, options) {
    set$2(key, '', Utils.extend(true, {}, options, {
      expires: -1
    }));
  }

  function has(key) {
    return get$1(key) !== undefined;
  }

  var Cookies = {
    get: get$1,
    set: set$2,
    has: has,
    remove: remove$1,
    all: function all() {
      return get$1();
    }
  };

var   vm$1 = void 0;
  var appIsInProgress = false;
  var timeout = void 0;
  var template$1 = '\n    <div class="quasar-loading fullscreen column items-center justify-center z-absolute">\n      <spinner :name="spinner" color="#fff" :size="80"></spinner>\n      <div v-if="message" style="margin: 40px 20px 0 20px; max-width: 450px; text-align: center; color: white; text-shadow: 0 0 7px black">{{ message }}</div>\n    </div>\n  ';

  function isActive$1() {
    return appIsInProgress;
  }

  function show() {
    var _ref = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];

    var _ref$delay = _ref.delay;
    var delay = _ref$delay === undefined ? 500 : _ref$delay;
    var _ref$spinner = _ref.spinner;
    var spinner = _ref$spinner === undefined ? theme === 'ios' ? 'ios' : 'tail' : _ref$spinner;
    var _ref$message = _ref.message;
    var message = _ref$message === undefined ? false : _ref$message;

    if (appIsInProgress) {
      vm$1.$data = { spinner: spinner, message: message };
      return;
    }

    timeout = setTimeout(function () {
      document.body.classList.add('dimmed');

      vm$1 = new Vue({
        template: template$1,
        data: {
          spinner: spinner,
          message: message
        }
      });

      vm$1.$mount().$appendTo(document.body);

      timeout = null;
    }, delay);

    appIsInProgress = true;
    Events.trigger('app:loading', true);
  }

  function hide() {
    if (!appIsInProgress) {
      return;
    }

    if (timeout) {
      clearTimeout(timeout);
      timeout = null;
    } else {
      document.body.classList.remove('dimmed');
      vm$1.$destroy(true);
    }

    appIsInProgress = false;
    Events.trigger('app:loading', false);
  }

  var Loading = {
    isActive: isActive$1,
    show: show,
    hide: hide
  };

  function encode$1(value) {
    if (Object.prototype.toString.call(value) === '[object Date]') {
      return '__q_date|' + value.toUTCString();
    }
    if (Object.prototype.toString.call(value) === '[object RegExp]') {
      return '__q_expr|' + value.source;
    }
    if (typeof value === 'number') {
      return '__q_numb|' + value;
    }
    if (typeof value === 'boolean') {
      return '__q_bool|' + (value ? '1' : '0');
    }
    if (typeof value === 'string') {
      return '__q_strn|' + value;
    }
    if (typeof value === 'function') {
      return '__q_strn|' + value.toString();
    }
    if (value === Object(value)) {
      return '__q_objt|' + JSON.stringify(value);
    }

    return value;
  }

  function decode$1(value) {
    var type = void 0,
        length = void 0,
        source = void 0;

    length = value.length;
    if (length < 10) {
      return value;
    }

    type = value.substr(0, 8);
    source = value.substring(9);

    switch (type) {
      case '__q_date':
        return new Date(source);

      case '__q_expr':
        return new RegExp(source);

      case '__q_numb':
        return Number(source);

      case '__q_bool':
        return Boolean(source === '1');

      case '__q_strn':
        return '' + source;

      case '__q_objt':
        return JSON.parse(source);

      default:
        return value;
    }
  }

  function generateFunctions(fn) {
    return {
      local: fn('local'),
      session: fn('session')
    };
  }

  var hasStorageItem = generateFunctions(function (type) {
    return function (key) {
      return window[type + 'Storage'].getItem(key) !== null;
    };
  });
  var getStorageLength = generateFunctions(function (type) {
    return function () {
      return window[type + 'Storage'].length;
    };
  });
  var getStorageItem = generateFunctions(function (type) {
    var hasFn = hasStorageItem[type],
        storage = window[type + 'Storage'];

    return function (key) {
      if (hasFn(key)) {
        return decode$1(storage.getItem(key));
      }
      return null;
    };
  });
  var getStorageAtIndex = generateFunctions(function (type) {
    var lengthFn = getStorageLength[type],
        getItemFn = getStorageItem[type],
        storage = window[type + 'Storage'];

    return function (index) {
      if (index < lengthFn()) {
        return getItemFn(storage.key(index));
      }
    };
  });
  var getAllStorageItems = generateFunctions(function (type) {
    var lengthFn = getStorageLength[type],
        storage = window[type + 'Storage'],
        getItemFn = getStorageItem[type];

    return function () {
      var result = {},
          key = void 0,
          length = lengthFn();

      for (var i = 0; i < length; i++) {
        key = storage.key(i);
        result[key] = getItemFn(key);
      }

      return result;
    };
  });
  var setStorageItem = generateFunctions(function (type) {
    var storage = window[type + 'Storage'];
    return function (key, value) {
      storage.setItem(key, encode$1(value));
    };
  });
  var removeStorageItem = generateFunctions(function (type) {
    var storage = window[type + 'Storage'];
    return function (key) {
      storage.removeItem(key);
    };
  });
  var clearStorage = generateFunctions(function (type) {
    var storage = window[type + 'Storage'];
    return function () {
      storage.clear();
    };
  });
  var storageIsEmpty = generateFunctions(function (type) {
    var getLengthFn = getStorageLength[type];
    return function () {
      return getLengthFn() === 0;
    };
  });
  var LocalStorage = {
    has: hasStorageItem.local,
    get: {
      length: getStorageLength.local,
      item: getStorageItem.local,
      index: getStorageAtIndex.local,
      all: getAllStorageItems.local
    },
    set: setStorageItem.local,
    remove: removeStorageItem.local,
    clear: clearStorage.local,
    isEmpty: storageIsEmpty.local
  };

  var SessionStorage = {
    has: hasStorageItem.session,
    get: {
      length: getStorageLength.session,
      item: getStorageItem.session,
      index: getStorageAtIndex.session,
      all: getAllStorageItems.session
    },
    set: setStorageItem.session,
    remove: removeStorageItem.session,
    clear: clearStorage.session,
    isEmpty: storageIsEmpty.session
  };

  window.Velocity = Velocity$1;
  var Quasar = {
    version: '0.5.0',
    install: install,
    start: start,
    theme: theme$1,

    ActionSheet: ActionSheet,
    Dialog: Dialog,
    AppFullscreen: AppFullscreen,
    AppVisibility: AppVisibility,
    Cookies: Cookies,
    Platform: Platform,
    Events: Events,
    Loading: Loading,
    Modal: Modal$1,
    Toast: Toast$1,
    Utils: Utils,
    LocalStorage: LocalStorage,
    SessionStorage: SessionStorage
  };

  init(Quasar);

  return Quasar;

}));